Class: Google::Apis::CloudkmsV1::AsymmetricDecryptResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

Response message for KeyManagementService.AsymmetricDecrypt.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AsymmetricDecryptResponse

Returns a new instance of AsymmetricDecryptResponse.



165
166
167
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 165

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#plaintextString

The decrypted data originally encrypted with the matching public key. Corresponds to the JSON property plaintext NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


131
132
133
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 131

def plaintext
  @plaintext
end

#plaintext_crc32cFixnum

Integrity verification field. A CRC32C checksum of the returned AsymmetricDecryptResponse.plaintext. An integrity check of AsymmetricDecryptResponse.plaintext can be performed by computing the CRC32C checksum of AsymmetricDecryptResponse.plaintext and comparing your results to this field. Discard the response in case of non-matching checksum values, and perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type. Corresponds to the JSON property plaintextCrc32c

Returns:

  • (Fixnum)


145
146
147
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 145

def plaintext_crc32c
  @plaintext_crc32c
end

#protection_levelString

The ProtectionLevel of the CryptoKeyVersion used in decryption. Corresponds to the JSON property protectionLevel

Returns:

  • (String)


150
151
152
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 150

def protection_level
  @protection_level
end

#verified_ciphertext_crc32cBoolean Also known as: verified_ciphertext_crc32c?

Integrity verification field. A flag indicating whether AsymmetricDecryptRequest.ciphertext_crc32c was received by KeyManagementService and used for the integrity verification of the ciphertext. A false value of this field indicates either that AsymmetricDecryptRequest. ciphertext_crc32c was left unset or that it was not delivered to KeyManagementService. If you've set AsymmetricDecryptRequest.ciphertext_crc32c but this field is still false, discard the response and perform a limited number of retries. Corresponds to the JSON property verifiedCiphertextCrc32c

Returns:

  • (Boolean)


162
163
164
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 162

def verified_ciphertext_crc32c
  @verified_ciphertext_crc32c
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



170
171
172
173
174
175
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 170

def update!(**args)
  @plaintext = args[:plaintext] if args.key?(:plaintext)
  @plaintext_crc32c = args[:plaintext_crc32c] if args.key?(:plaintext_crc32c)
  @protection_level = args[:protection_level] if args.key?(:protection_level)
  @verified_ciphertext_crc32c = args[:verified_ciphertext_crc32c] if args.key?(:verified_ciphertext_crc32c)
end