Class: Google::Apis::CloudkmsV1::AsymmetricSignRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

Request message for KeyManagementService.AsymmetricSign.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AsymmetricSignRequest

Returns a new instance of AsymmetricSignRequest.



224
225
226
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 224

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataString

Optional. The data to sign. It can't be supplied if AsymmetricSignRequest. digest is supplied. Corresponds to the JSON property data NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


187
188
189
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 187

def data
  @data
end

#data_crc32cFixnum

Optional. An optional CRC32C checksum of the AsymmetricSignRequest.data. If specified, KeyManagementService will verify the integrity of the received AsymmetricSignRequest.data using this checksum. KeyManagementService will report an error if the checksum verification fails. If you receive a checksum error, your client should verify that CRC32C(AsymmetricSignRequest.data) is equal to AsymmetricSignRequest.data_crc32c, and if so, perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non- negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type. Corresponds to the JSON property dataCrc32c

Returns:

  • (Fixnum)


202
203
204
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 202

def data_crc32c
  @data_crc32c
end

#digestGoogle::Apis::CloudkmsV1::Digest

A Digest holds a cryptographic message digest. Corresponds to the JSON property digest



207
208
209
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 207

def digest
  @digest
end

#digest_crc32cFixnum

Optional. An optional CRC32C checksum of the AsymmetricSignRequest.digest. If specified, KeyManagementService will verify the integrity of the received AsymmetricSignRequest.digest using this checksum. KeyManagementService will report an error if the checksum verification fails. If you receive a checksum error, your client should verify that CRC32C(AsymmetricSignRequest.digest) is equal to AsymmetricSignRequest.digest_crc32c, and if so, perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non- negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type. Corresponds to the JSON property digestCrc32c

Returns:

  • (Fixnum)


222
223
224
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 222

def digest_crc32c
  @digest_crc32c
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



229
230
231
232
233
234
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 229

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @data_crc32c = args[:data_crc32c] if args.key?(:data_crc32c)
  @digest = args[:digest] if args.key?(:digest)
  @digest_crc32c = args[:digest_crc32c] if args.key?(:digest_crc32c)
end