Class: Google::Apis::CloudkmsV1::AsymmetricSignResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::AsymmetricSignResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
Response message for KeyManagementService.AsymmetricSign.
Instance Attribute Summary collapse
-
#name ⇒ String
The resource name of the CryptoKeyVersion used for signing.
-
#protection_level ⇒ String
The ProtectionLevel of the CryptoKeyVersion used for signing.
-
#signature ⇒ String
The created signature.
-
#signature_crc32c ⇒ Fixnum
Integrity verification field.
-
#verified_data_crc32c ⇒ Boolean
(also: #verified_data_crc32c?)
Integrity verification field.
-
#verified_digest_crc32c ⇒ Boolean
(also: #verified_digest_crc32c?)
Integrity verification field.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AsymmetricSignResponse
constructor
A new instance of AsymmetricSignResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AsymmetricSignResponse
Returns a new instance of AsymmetricSignResponse.
296 297 298 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 296 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The resource name of the CryptoKeyVersion used for signing. Check this field
to verify that the intended resource was used for signing.
Corresponds to the JSON property name
245 246 247 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 245 def name @name end |
#protection_level ⇒ String
The ProtectionLevel of the CryptoKeyVersion used for signing.
Corresponds to the JSON property protectionLevel
250 251 252 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 250 def protection_level @protection_level end |
#signature ⇒ String
The created signature.
Corresponds to the JSON property signature
NOTE: Values are automatically base64 encoded/decoded in the client library.
256 257 258 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 256 def signature @signature end |
#signature_crc32c ⇒ Fixnum
Integrity verification field. A CRC32C checksum of the returned
AsymmetricSignResponse.signature. An integrity check of AsymmetricSignResponse.
signature can be performed by computing the CRC32C checksum of
AsymmetricSignResponse.signature and comparing your results to this field.
Discard the response in case of non-matching checksum values, and perform a
limited number of retries. A persistent mismatch may indicate an issue in your
computation of the CRC32C checksum. Note: This field is defined as int64 for
reasons of compatibility across different languages. However, it is a non-
negative integer, which will never exceed 2^32-1, and can be safely
downconverted to uint32 in languages that support this type.
Corresponds to the JSON property signatureCrc32c
270 271 272 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 270 def signature_crc32c @signature_crc32c end |
#verified_data_crc32c ⇒ Boolean Also known as: verified_data_crc32c?
Integrity verification field. A flag indicating whether AsymmetricSignRequest.
data_crc32c was received by KeyManagementService and used for the integrity
verification of the data. A false value of this field indicates either that
AsymmetricSignRequest.data_crc32c was left unset or that it was not delivered
to KeyManagementService. If you've set AsymmetricSignRequest.data_crc32c but
this field is still false, discard the response and perform a limited number
of retries.
Corresponds to the JSON property verifiedDataCrc32c
281 282 283 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 281 def verified_data_crc32c @verified_data_crc32c end |
#verified_digest_crc32c ⇒ Boolean Also known as: verified_digest_crc32c?
Integrity verification field. A flag indicating whether AsymmetricSignRequest.
digest_crc32c was received by KeyManagementService and used for the integrity
verification of the digest. A false value of this field indicates either that
AsymmetricSignRequest.digest_crc32c was left unset or that it was not
delivered to KeyManagementService. If you've set AsymmetricSignRequest.
digest_crc32c but this field is still false, discard the response and perform
a limited number of retries.
Corresponds to the JSON property verifiedDigestCrc32c
293 294 295 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 293 def verified_digest_crc32c @verified_digest_crc32c end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
301 302 303 304 305 306 307 308 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 301 def update!(**args) @name = args[:name] if args.key?(:name) @protection_level = args[:protection_level] if args.key?(:protection_level) @signature = args[:signature] if args.key?(:signature) @signature_crc32c = args[:signature_crc32c] if args.key?(:signature_crc32c) @verified_data_crc32c = args[:verified_data_crc32c] if args.key?(:verified_data_crc32c) @verified_digest_crc32c = args[:verified_digest_crc32c] if args.key?(:verified_digest_crc32c) end |