Class: Google::Apis::CloudkmsV1::AutokeyConfig
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::AutokeyConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
Cloud KMS Autokey configuration for a folder.
Instance Attribute Summary collapse
-
#etag ⇒ String
Optional.
-
#key_project ⇒ String
Optional.
-
#key_project_resolution_mode ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutokeyConfig
constructor
A new instance of AutokeyConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutokeyConfig
Returns a new instance of AutokeyConfig.
423 424 425 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 423 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Optional. A checksum computed by the server based on the value of other fields.
This may be sent on update requests to ensure that the client has an up-to-
date value before proceeding. The request will be rejected with an ABORTED
error on a mismatched etag.
Corresponds to the JSON property etag
392 393 394 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 392 def etag @etag end |
#key_project ⇒ String
Optional. Name of the key project, e.g. projects/PROJECT_IDor `projects/`
PROJECT_NUMBER, where Cloud KMS Autokey will provision a new CryptoKey when
a KeyHandle is created. On UpdateAutokeyConfig, the caller will require
cloudkms.cryptoKeys.setIamPolicy permission on this key project. Once
configured, for Cloud KMS Autokey to function properly, this key project must
have the Cloud KMS API activated and the Cloud KMS Service Agent for this key
project must be granted the cloudkms.admin role (or pertinent permissions).
A request with an empty key project field will clear the configuration.
Corresponds to the JSON property keyProject
404 405 406 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 404 def key_project @key_project end |
#key_project_resolution_mode ⇒ String
Optional. KeyProjectResolutionMode for the AutokeyConfig. Valid values are
DEDICATED_KEY_PROJECT, RESOURCE_PROJECT, or DISABLED.
Corresponds to the JSON property keyProjectResolutionMode
410 411 412 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 410 def key_project_resolution_mode @key_project_resolution_mode end |
#name ⇒ String
Identifier. Name of the AutokeyConfig resource, e.g. folders/FOLDER_NUMBER/
autokeyConfig or projects/PROJECT_NUMBER/autokeyConfig.
Corresponds to the JSON property name
416 417 418 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 416 def name @name end |
#state ⇒ String
Output only. The state for the AutokeyConfig.
Corresponds to the JSON property state
421 422 423 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 421 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
428 429 430 431 432 433 434 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 428 def update!(**args) @etag = args[:etag] if args.key?(:etag) @key_project = args[:key_project] if args.key?(:key_project) @key_project_resolution_mode = args[:key_project_resolution_mode] if args.key?(:key_project_resolution_mode) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) end |