Class: Google::Apis::CloudkmsV1::DecapsulateRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

Request message for KeyManagementService.Decapsulate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DecapsulateRequest

Returns a new instance of DecapsulateRequest.



1042
1043
1044
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1042

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ciphertextString

Required. The ciphertext produced from encapsulation with the named CryptoKeyVersion public key(s). Corresponds to the JSON property ciphertext NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1025
1026
1027
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1025

def ciphertext
  @ciphertext
end

#ciphertext_crc32cFixnum

Optional. A CRC32C checksum of the DecapsulateRequest.ciphertext. If specified, KeyManagementService will verify the integrity of the received DecapsulateRequest.ciphertext using this checksum. KeyManagementService will report an error if the checksum verification fails. If you receive a checksum error, your client should verify that CRC32C(DecapsulateRequest.ciphertext) is equal to DecapsulateRequest.ciphertext_crc32c, and if so, perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non- negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type. Corresponds to the JSON property ciphertextCrc32c

Returns:

  • (Fixnum)


1040
1041
1042
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1040

def ciphertext_crc32c
  @ciphertext_crc32c
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1047
1048
1049
1050
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1047

def update!(**args)
  @ciphertext = args[:ciphertext] if args.key?(:ciphertext)
  @ciphertext_crc32c = args[:ciphertext_crc32c] if args.key?(:ciphertext_crc32c)
end