Class: Google::Apis::CloudkmsV1::DecryptRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

Request message for KeyManagementService.Decrypt.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DecryptRequest

Returns a new instance of DecryptRequest.



1186
1187
1188
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1186

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_authenticated_dataString

Optional. Optional data that must match the data originally supplied in EncryptRequest.additional_authenticated_data. Corresponds to the JSON property additionalAuthenticatedData NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1147
1148
1149
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1147

def additional_authenticated_data
  @additional_authenticated_data
end

#additional_authenticated_data_crc32cFixnum

Optional. An optional CRC32C checksum of the DecryptRequest. additional_authenticated_data. If specified, KeyManagementService will verify the integrity of the received DecryptRequest.additional_authenticated_data using this checksum. KeyManagementService will report an error if the checksum verification fails. If you receive a checksum error, your client should verify that CRC32C(DecryptRequest.additional_authenticated_data) is equal to DecryptRequest.additional_authenticated_data_crc32c, and if so, perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non- negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type. Corresponds to the JSON property additionalAuthenticatedDataCrc32c

Returns:

  • (Fixnum)


1163
1164
1165
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1163

def additional_authenticated_data_crc32c
  @additional_authenticated_data_crc32c
end

#ciphertextString

Required. The encrypted data originally returned in EncryptResponse.ciphertext. Corresponds to the JSON property ciphertext NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1169
1170
1171
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1169

def ciphertext
  @ciphertext
end

#ciphertext_crc32cFixnum

Optional. An optional CRC32C checksum of the DecryptRequest.ciphertext. If specified, KeyManagementService will verify the integrity of the received DecryptRequest.ciphertext using this checksum. KeyManagementService will report an error if the checksum verification fails. If you receive a checksum error, your client should verify that CRC32C(DecryptRequest.ciphertext) is equal to DecryptRequest.ciphertext_crc32c, and if so, perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type. Corresponds to the JSON property ciphertextCrc32c

Returns:

  • (Fixnum)


1184
1185
1186
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1184

def ciphertext_crc32c
  @ciphertext_crc32c
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1191
1192
1193
1194
1195
1196
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1191

def update!(**args)
  @additional_authenticated_data = args[:additional_authenticated_data] if args.key?(:additional_authenticated_data)
  @additional_authenticated_data_crc32c = args[:additional_authenticated_data_crc32c] if args.key?(:additional_authenticated_data_crc32c)
  @ciphertext = args[:ciphertext] if args.key?(:ciphertext)
  @ciphertext_crc32c = args[:ciphertext_crc32c] if args.key?(:ciphertext_crc32c)
end