Class: Google::Apis::CloudkmsV1::EkmConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

An EkmConfig is a singleton resource that represents configuration parameters that apply to all CryptoKeys and CryptoKeyVersions with a ProtectionLevel of EXTERNAL_VPC in a given project and location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EkmConfig

Returns a new instance of EkmConfig.



1332
1333
1334
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1332

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_ekm_connectionString

Optional. Resource name of the default EkmConnection. Setting this field to the empty string removes the default. Corresponds to the JSON property defaultEkmConnection

Returns:

  • (String)


1324
1325
1326
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1324

def default_ekm_connection
  @default_ekm_connection
end

#nameString

Output only. The resource name for the EkmConfig in the format projects/*/ locations/*/ekmConfig. Corresponds to the JSON property name

Returns:

  • (String)


1330
1331
1332
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1330

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1337
1338
1339
1340
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1337

def update!(**args)
  @default_ekm_connection = args[:default_ekm_connection] if args.key?(:default_ekm_connection)
  @name = args[:name] if args.key?(:name)
end