Class: Google::Apis::CloudkmsV1::ExportTrustedKeyWrappedCryptoKeyVersionResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

Response message for KeyManagementService. ExportTrustedKeyWrappedCryptoKeyVersion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExportTrustedKeyWrappedCryptoKeyVersionResponse

Returns a new instance of ExportTrustedKeyWrappedCryptoKeyVersionResponse.



1633
1634
1635
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1633

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#wrapped_keyString

The wrapped key material. Corresponds to the JSON property wrappedKey NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1616
1617
1618
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1616

def wrapped_key
  @wrapped_key
end

#wrapped_key_crc32cFixnum

Integrity verification field. A CRC32C checksum of the returned ExportTrustedKeyWrappedCryptoKeyVersionResponse.wrapped_key. An integrity check of ExportTrustedKeyWrappedCryptoKeyVersionResponse.wrapped_key can be performed by computing the CRC32C checksum of ExportTrustedKeyWrappedCryptoKeyVersionResponse.wrapped_key and comparing your results to this field. Discard the response in case of non-matching checksum values, and perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type. Corresponds to the JSON property wrappedKeyCrc32c

Returns:

  • (Fixnum)


1631
1632
1633
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1631

def wrapped_key_crc32c
  @wrapped_key_crc32c
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1638
1639
1640
1641
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1638

def update!(**args)
  @wrapped_key = args[:wrapped_key] if args.key?(:wrapped_key)
  @wrapped_key_crc32c = args[:wrapped_key_crc32c] if args.key?(:wrapped_key_crc32c)
end