Class: Google::Apis::CloudkmsV1::GenerateRandomBytesResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

Response message for KeyManagementService.GenerateRandomBytes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenerateRandomBytesResponse

Returns a new instance of GenerateRandomBytesResponse.



1718
1719
1720
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1718

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataString

The generated data. Corresponds to the JSON property data NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1702
1703
1704
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1702

def data
  @data
end

#data_crc32cFixnum

Integrity verification field. A CRC32C checksum of the returned GenerateRandomBytesResponse.data. An integrity check of GenerateRandomBytesResponse.data can be performed by computing the CRC32C checksum of GenerateRandomBytesResponse.data and comparing your results to this field. Discard the response in case of non-matching checksum values, and perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type. Corresponds to the JSON property dataCrc32c

Returns:

  • (Fixnum)


1716
1717
1718
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1716

def data_crc32c
  @data_crc32c
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1723
1724
1725
1726
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1723

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @data_crc32c = args[:data_crc32c] if args.key?(:data_crc32c)
end