Class: Google::Apis::CloudkmsV1::ImportCryptoKeyVersionRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

Request message for KeyManagementService.ImportCryptoKeyVersion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportCryptoKeyVersionRequest

Returns a new instance of ImportCryptoKeyVersionRequest.



1864
1865
1866
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1864

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#algorithmString

Required. The algorithm of the key being imported. This does not need to match the version_template of the CryptoKey this version imports into. Corresponds to the JSON property algorithm

Returns:

  • (String)


1807
1808
1809
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1807

def algorithm
  @algorithm
end

#crypto_key_versionString

Optional. The optional name of an existing CryptoKeyVersion to target for an import operation. If this field is not present, a new CryptoKeyVersion containing the supplied key material is created. If this field is present, the supplied key material is imported into the existing CryptoKeyVersion. To import into an existing CryptoKeyVersion, the CryptoKeyVersion must be a child of ImportCryptoKeyVersionRequest.parent, have been previously created via ImportCryptoKeyVersion, and be in DESTROYED or IMPORT_FAILED state. The key material and algorithm must match the previous CryptoKeyVersion exactly if the CryptoKeyVersion has ever contained key material. Corresponds to the JSON property cryptoKeyVersion

Returns:

  • (String)


1820
1821
1822
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1820

def crypto_key_version
  @crypto_key_version
end

#import_jobString

Required. The name of the ImportJob that was used to wrap this key material. Corresponds to the JSON property importJob

Returns:

  • (String)


1825
1826
1827
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1825

def import_job
  @import_job
end

#rsa_aes_wrapped_keyString

Optional. This field has the same meaning as wrapped_key. Prefer to use that field in new work. Either that field or this field (but not both) must be specified. Corresponds to the JSON property rsaAesWrappedKey NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1833
1834
1835
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1833

def rsa_aes_wrapped_key
  @rsa_aes_wrapped_key
end

#trusted_wrapping_enabledBoolean Also known as: trusted_wrapping_enabled?

Optional. Whether trusted wrapping will be enabled on the imported [ CryptoKeyVersion]. This field is only supported for keys with CryptoKeyVersionTemplate.protection_level HSM_SINGLE_TENANT. This field is supported for all CryptoKeyPurposes besides ENCRYPT_DECRYPT. Corresponds to the JSON property trustedWrappingEnabled

Returns:

  • (Boolean)


1841
1842
1843
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1841

def trusted_wrapping_enabled
  @trusted_wrapping_enabled
end

#wrapped_keyString

Optional. The wrapped key material to import. Before wrapping, key material must be formatted. If importing symmetric key material, the expected key material format is plain bytes. If importing asymmetric key material, the expected key material format is PKCS#8-encoded DER (the PrivateKeyInfo structure from RFC 5208). When wrapping with import methods ( RSA_OAEP_3072_SHA1_AES_256 or RSA_OAEP_4096_SHA1_AES_256 or RSA_OAEP_3072_SHA256_AES_256 or RSA_OAEP_4096_SHA256_AES_256), this field must contain the concatenation of: 1. An ephemeral AES-256 wrapping key wrapped with the public_key using RSAES-OAEP with SHA-1/SHA-256, MGF1 with SHA-1/SHA- 256, and an empty label. 2. The formatted key to be imported, wrapped with the ephemeral AES-256 key using AES-KWP (RFC 5649). This format is the same as the format produced by PKCS#11 mechanism CKM_RSA_AES_KEY_WRAP. When wrapping with import methods (RSA_OAEP_3072_SHA256 or RSA_OAEP_4096_SHA256), this field must contain the formatted key to be imported, wrapped with the public_key using RSAES-OAEP with SHA-256, MGF1 with SHA-256, and an empty label. Corresponds to the JSON property wrappedKey NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1862
1863
1864
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1862

def wrapped_key
  @wrapped_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1869
1870
1871
1872
1873
1874
1875
1876
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1869

def update!(**args)
  @algorithm = args[:algorithm] if args.key?(:algorithm)
  @crypto_key_version = args[:crypto_key_version] if args.key?(:crypto_key_version)
  @import_job = args[:import_job] if args.key?(:import_job)
  @rsa_aes_wrapped_key = args[:rsa_aes_wrapped_key] if args.key?(:rsa_aes_wrapped_key)
  @trusted_wrapping_enabled = args[:trusted_wrapping_enabled] if args.key?(:trusted_wrapping_enabled)
  @wrapped_key = args[:wrapped_key] if args.key?(:wrapped_key)
end