Class: Google::Apis::CloudkmsV1::ImportTrustedKeyWrappedCryptoKeyVersionRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

Request message for KeyManagementService. ImportTrustedKeyWrappedCryptoKeyVersion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportTrustedKeyWrappedCryptoKeyVersionRequest

Returns a new instance of ImportTrustedKeyWrappedCryptoKeyVersionRequest.



2030
2031
2032
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2030

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#algorithmString

Required. Required - The algorithm of the key being imported. This does not need to match the version_template of the CryptoKey this version imports into. Corresponds to the JSON property algorithm

Returns:

  • (String)


2002
2003
2004
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2002

def algorithm
  @algorithm
end

#crypto_key_versionString

Optional. The optional name of an existing CryptoKeyVersion to target for an import operation. If this field is not present, a new CryptoKeyVersion containing the supplied key material is created. If this field is present, the supplied key material is imported into the existing CryptoKeyVersion. To import into an existing CryptoKeyVersion, the CryptoKeyVersion must be a child of ImportTrustedKeyWrappedCryptoKeyVersionRequest.parent, have been previously created via ImportTrustedKeyWrappedCryptoKeyVersion, and be in DESTROYED or IMPORT_FAILED state. The key material and algorithm must match the previous CryptoKeyVersion exactly if the CryptoKeyVersion has ever contained key material Corresponds to the JSON property cryptoKeyVersion

Returns:

  • (String)


2016
2017
2018
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2016

def crypto_key_version
  @crypto_key_version
end

#importing_keyString

Required. Required - the CKV of the trusted key used to import. This can be the name of a CryptoKeyVersion or a CryptoKey. Corresponds to the JSON property importingKey

Returns:

  • (String)


2022
2023
2024
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2022

def importing_key
  @importing_key
end

#wrapped_keyString

Required. The target key pre-wrapped on premises. Corresponds to the JSON property wrappedKey NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


2028
2029
2030
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2028

def wrapped_key
  @wrapped_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2035
2036
2037
2038
2039
2040
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2035

def update!(**args)
  @algorithm = args[:algorithm] if args.key?(:algorithm)
  @crypto_key_version = args[:crypto_key_version] if args.key?(:crypto_key_version)
  @importing_key = args[:importing_key] if args.key?(:importing_key)
  @wrapped_key = args[:wrapped_key] if args.key?(:wrapped_key)
end