Class: Google::Apis::CloudkmsV1::KeyAccessJustificationsPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

A KeyAccessJustificationsPolicy specifies zero or more allowed AccessReason values for encrypt, decrypt, and sign operations on a CryptoKey or KeyAccessJustificationsPolicyConfig (the default Key Access Justifications policy).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KeyAccessJustificationsPolicy

Returns a new instance of KeyAccessJustificationsPolicy.



1951
1952
1953
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1951

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_access_reasonsArray<String>

The list of allowed reasons for access to a CryptoKey. Note that empty allowed_access_reasons has a different meaning depending on where this message appears. If this is under KeyAccessJustificationsPolicyConfig, it means allow- all. If this is under CryptoKey, it means deny-all. Corresponds to the JSON property allowedAccessReasons

Returns:

  • (Array<String>)


1949
1950
1951
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1949

def allowed_access_reasons
  @allowed_access_reasons
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1956
1957
1958
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1956

def update!(**args)
  @allowed_access_reasons = args[:allowed_access_reasons] if args.key?(:allowed_access_reasons)
end