Class: Google::Apis::CloudkmsV1::KeyAccessJustificationsPolicyConfig
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::KeyAccessJustificationsPolicyConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
Represents a singleton configuration for Key Access Justifications policies.
Instance Attribute Summary collapse
-
#default_key_access_justification_policy ⇒ Google::Apis::CloudkmsV1::KeyAccessJustificationsPolicy
A KeyAccessJustificationsPolicy specifies zero or more allowed AccessReason values for encrypt, decrypt, and sign operations on a CryptoKey or KeyAccessJustificationsPolicyConfig (the default Key Access Justifications policy).
-
#default_policy_available ⇒ Boolean
(also: #default_policy_available?)
Output only.
-
#name ⇒ String
Identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KeyAccessJustificationsPolicyConfig
constructor
A new instance of KeyAccessJustificationsPolicyConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ KeyAccessJustificationsPolicyConfig
Returns a new instance of KeyAccessJustificationsPolicyConfig.
2124 2125 2126 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2124 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_key_access_justification_policy ⇒ Google::Apis::CloudkmsV1::KeyAccessJustificationsPolicy
A KeyAccessJustificationsPolicy specifies zero or more allowed AccessReason
values for encrypt, decrypt, and sign operations on a CryptoKey or
KeyAccessJustificationsPolicyConfig (the default Key Access Justifications
policy).
Corresponds to the JSON property defaultKeyAccessJustificationPolicy
2106 2107 2108 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2106 def default_key_access_justification_policy @default_key_access_justification_policy end |
#default_policy_available ⇒ Boolean Also known as: default_policy_available?
Output only. Indicates whether this parent resource is available to default
policy feature. Please consult the prerequisite of default policy feature for more details.
Corresponds to the JSON property defaultPolicyAvailable
2114 2115 2116 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2114 def default_policy_available @default_policy_available end |
#name ⇒ String
Identifier. Represents the resource name for this
KeyAccessJustificationsPolicyConfig in the format of "organizations|folders|
projects/*/kajPolicyConfig".
Corresponds to the JSON property name
2122 2123 2124 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2122 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2129 2130 2131 2132 2133 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2129 def update!(**args) @default_key_access_justification_policy = args[:default_key_access_justification_policy] if args.key?(:default_key_access_justification_policy) @default_policy_available = args[:default_policy_available] if args.key?(:default_policy_available) @name = args[:name] if args.key?(:name) end |