Class: Google::Apis::CloudkmsV1::ListRetiredResourcesResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::ListRetiredResourcesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
Response message for KeyManagementService.ListRetiredResources.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#retired_resources ⇒ Array<Google::Apis::CloudkmsV1::RetiredResource>
The list of RetiredResources.
-
#total_size ⇒ Fixnum
The total number of RetiredResources that matched the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListRetiredResourcesResponse
constructor
A new instance of ListRetiredResourcesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListRetiredResourcesResponse
Returns a new instance of ListRetiredResourcesResponse.
2322 2323 2324 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2322 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in
ListRetiredResourcesRequest.page_token to retrieve the next page of results.
Corresponds to the JSON property nextPageToken
2310 2311 2312 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2310 def next_page_token @next_page_token end |
#retired_resources ⇒ Array<Google::Apis::CloudkmsV1::RetiredResource>
The list of RetiredResources.
Corresponds to the JSON property retiredResources
2315 2316 2317 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2315 def retired_resources @retired_resources end |
#total_size ⇒ Fixnum
The total number of RetiredResources that matched the query.
Corresponds to the JSON property totalSize
2320 2321 2322 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2320 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2327 2328 2329 2330 2331 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2327 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @retired_resources = args[:retired_resources] if args.key?(:retired_resources) @total_size = args[:total_size] if args.key?(:total_size) end |