Class: Google::Apis::CloudkmsV1::MacSignRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::MacSignRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
Request message for KeyManagementService.MacSign.
Instance Attribute Summary collapse
-
#data ⇒ String
Required.
-
#data_crc32c ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MacSignRequest
constructor
A new instance of MacSignRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MacSignRequest
Returns a new instance of MacSignRequest.
2532 2533 2534 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2532 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ String
Required. The data to sign. The MAC tag is computed over this data field based
on the specific algorithm.
Corresponds to the JSON property data
NOTE: Values are automatically base64 encoded/decoded in the client library.
2515 2516 2517 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2515 def data @data end |
#data_crc32c ⇒ Fixnum
Optional. An optional CRC32C checksum of the MacSignRequest.data. If specified,
KeyManagementService will verify the integrity of the received MacSignRequest.
data using this checksum. KeyManagementService will report an error if the
checksum verification fails. If you receive a checksum error, your client
should verify that CRC32C(MacSignRequest.data) is equal to MacSignRequest.
data_crc32c, and if so, perform a limited number of retries. A persistent
mismatch may indicate an issue in your computation of the CRC32C checksum.
Note: This field is defined as int64 for reasons of compatibility across
different languages. However, it is a non-negative integer, which will never
exceed 2^32-1, and can be safely downconverted to uint32 in languages that
support this type.
Corresponds to the JSON property dataCrc32c
2530 2531 2532 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2530 def data_crc32c @data_crc32c end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2537 2538 2539 2540 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2537 def update!(**args) @data = args[:data] if args.key?(:data) @data_crc32c = args[:data_crc32c] if args.key?(:data_crc32c) end |