Class: Google::Apis::CloudkmsV1::MacSignResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

Response message for KeyManagementService.MacSign.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MacSignResponse

Returns a new instance of MacSignResponse.



2724
2725
2726
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2724

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#macString

The created signature. Corresponds to the JSON property mac NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


2686
2687
2688
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2686

def mac
  @mac
end

#mac_crc32cFixnum

Integrity verification field. A CRC32C checksum of the returned MacSignResponse.mac. An integrity check of MacSignResponse.mac can be performed by computing the CRC32C checksum of MacSignResponse.mac and comparing your results to this field. Discard the response in case of non- matching checksum values, and perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type. Corresponds to the JSON property macCrc32c

Returns:

  • (Fixnum)


2700
2701
2702
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2700

def mac_crc32c
  @mac_crc32c
end

#nameString

The resource name of the CryptoKeyVersion used for signing. Check this field to verify that the intended resource was used for signing. Corresponds to the JSON property name

Returns:

  • (String)


2706
2707
2708
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2706

def name
  @name
end

#protection_levelString

The ProtectionLevel of the CryptoKeyVersion used for signing. Corresponds to the JSON property protectionLevel

Returns:

  • (String)


2711
2712
2713
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2711

def protection_level
  @protection_level
end

#verified_data_crc32cBoolean Also known as: verified_data_crc32c?

Integrity verification field. A flag indicating whether MacSignRequest. data_crc32c was received by KeyManagementService and used for the integrity verification of the data. A false value of this field indicates either that MacSignRequest.data_crc32c was left unset or that it was not delivered to KeyManagementService. If you've set MacSignRequest.data_crc32c but this field is still false, discard the response and perform a limited number of retries. Corresponds to the JSON property verifiedDataCrc32c

Returns:

  • (Boolean)


2721
2722
2723
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2721

def verified_data_crc32c
  @verified_data_crc32c
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2729
2730
2731
2732
2733
2734
2735
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2729

def update!(**args)
  @mac = args[:mac] if args.key?(:mac)
  @mac_crc32c = args[:mac_crc32c] if args.key?(:mac_crc32c)
  @name = args[:name] if args.key?(:name)
  @protection_level = args[:protection_level] if args.key?(:protection_level)
  @verified_data_crc32c = args[:verified_data_crc32c] if args.key?(:verified_data_crc32c)
end