Class: Google::Apis::CloudkmsV1::QuorumAuth

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

Configuration for M of N quorum auth.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuorumAuth

Returns a new instance of QuorumAuth.



2963
2964
2965
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2963

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#required_approver_countFixnum

Output only. The required numbers of approvers. The M value used for M of N quorum auth. Must be greater than or equal to 2 and less than or equal to total_approver_count - 1. Corresponds to the JSON property requiredApproverCount

Returns:

  • (Fixnum)


2949
2950
2951
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2949

def required_approver_count
  @required_approver_count
end

#total_approver_countFixnum

Required. The total number of approvers. This is the N value used for M of N quorum auth. Must be greater than or equal to 3 and less than or equal to 16. Corresponds to the JSON property totalApproverCount

Returns:

  • (Fixnum)


2955
2956
2957
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2955

def total_approver_count
  @total_approver_count
end

#two_factor_public_key_pemsArray<String>

Output only. The public keys associated with the 2FA keys for M of N quorum auth. Corresponds to the JSON property twoFactorPublicKeyPems

Returns:

  • (Array<String>)


2961
2962
2963
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2961

def two_factor_public_key_pems
  @two_factor_public_key_pems
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2968
2969
2970
2971
2972
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2968

def update!(**args)
  @required_approver_count = args[:required_approver_count] if args.key?(:required_approver_count)
  @total_approver_count = args[:total_approver_count] if args.key?(:total_approver_count)
  @two_factor_public_key_pems = args[:two_factor_public_key_pems] if args.key?(:two_factor_public_key_pems)
end