Class: Google::Apis::CloudkmsV1::QuorumParameters
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::QuorumParameters
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
Parameters of quorum approval for the SingleTenantHsmInstanceProposal.
Instance Attribute Summary collapse
-
#approved_two_factor_public_key_pems ⇒ Array<String>
Output only.
-
#challenges ⇒ Array<Google::Apis::CloudkmsV1::Challenge>
Output only.
-
#required_approver_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QuorumParameters
constructor
A new instance of QuorumParameters.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QuorumParameters
Returns a new instance of QuorumParameters.
3150 3151 3152 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3150 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approved_two_factor_public_key_pems ⇒ Array<String>
Output only. The public keys associated with the 2FA keys that have already
approved the SingleTenantHsmInstanceProposal by signing the challenge.
Corresponds to the JSON property approvedTwoFactorPublicKeyPems
3136 3137 3138 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3136 def approved_two_factor_public_key_pems @approved_two_factor_public_key_pems end |
#challenges ⇒ Array<Google::Apis::CloudkmsV1::Challenge>
Output only. The challenges to be signed by 2FA keys for quorum auth. M of N
of these challenges are required to be signed to approve the operation.
Corresponds to the JSON property challenges
3142 3143 3144 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3142 def challenges @challenges end |
#required_approver_count ⇒ Fixnum
Output only. The required numbers of approvers. This is the M value used for M
of N quorum auth. It is less than the number of public keys.
Corresponds to the JSON property requiredApproverCount
3148 3149 3150 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3148 def required_approver_count @required_approver_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3155 3156 3157 3158 3159 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3155 def update!(**args) @approved_two_factor_public_key_pems = args[:approved_two_factor_public_key_pems] if args.key?(:approved_two_factor_public_key_pems) @challenges = args[:challenges] if args.key?(:challenges) @required_approver_count = args[:required_approver_count] if args.key?(:required_approver_count) end |