Class: Google::Apis::CloudkmsV1::RawDecryptResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

Response message for KeyManagementService.RawDecrypt.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RawDecryptResponse

Returns a new instance of RawDecryptResponse.



3208
3209
3210
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3208

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#plaintextString

The decrypted data. Corresponds to the JSON property plaintext NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3149
3150
3151
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3149

def plaintext
  @plaintext
end

#plaintext_crc32cFixnum

Integrity verification field. A CRC32C checksum of the returned RawDecryptResponse.plaintext. An integrity check of plaintext can be performed by computing the CRC32C checksum of plaintext and comparing your results to this field. Discard the response in case of non-matching checksum values, and perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: receiving this response message indicates that KeyManagementService is able to successfully decrypt the ciphertext. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type. Corresponds to the JSON property plaintextCrc32c

Returns:

  • (Fixnum)


3164
3165
3166
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3164

def plaintext_crc32c
  @plaintext_crc32c
end

#protection_levelString

The ProtectionLevel of the CryptoKeyVersion used in decryption. Corresponds to the JSON property protectionLevel

Returns:

  • (String)


3169
3170
3171
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3169

def protection_level
  @protection_level
end

#verified_additional_authenticated_data_crc32cBoolean Also known as: verified_additional_authenticated_data_crc32c?

Integrity verification field. A flag indicating whether RawDecryptRequest. additional_authenticated_data_crc32c was received by KeyManagementService and used for the integrity verification of additional_authenticated_data. A false value of this field indicates either that // RawDecryptRequest. additional_authenticated_data_crc32c was left unset or that it was not delivered to KeyManagementService. If you've set RawDecryptRequest. additional_authenticated_data_crc32c but this field is still false, discard the response and perform a limited number of retries. Corresponds to the JSON property verifiedAdditionalAuthenticatedDataCrc32c

Returns:

  • (Boolean)


3181
3182
3183
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3181

def verified_additional_authenticated_data_crc32c
  @verified_additional_authenticated_data_crc32c
end

#verified_ciphertext_crc32cBoolean Also known as: verified_ciphertext_crc32c?

Integrity verification field. A flag indicating whether RawDecryptRequest. ciphertext_crc32c was received by KeyManagementService and used for the integrity verification of the ciphertext. A false value of this field indicates either that RawDecryptRequest.ciphertext_crc32c was left unset or that it was not delivered to KeyManagementService. If you've set RawDecryptRequest.ciphertext_crc32c but this field is still false, discard the response and perform a limited number of retries. Corresponds to the JSON property verifiedCiphertextCrc32c

Returns:

  • (Boolean)


3193
3194
3195
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3193

def verified_ciphertext_crc32c
  @verified_ciphertext_crc32c
end

#verified_initialization_vector_crc32cBoolean Also known as: verified_initialization_vector_crc32c?

Integrity verification field. A flag indicating whether RawDecryptRequest. initialization_vector_crc32c was received by KeyManagementService and used for the integrity verification of initialization_vector. A false value of this field indicates either that RawDecryptRequest.initialization_vector_crc32c was left unset or that it was not delivered to KeyManagementService. If you've set RawDecryptRequest.initialization_vector_crc32c but this field is still false, discard the response and perform a limited number of retries. Corresponds to the JSON property verifiedInitializationVectorCrc32c

Returns:

  • (Boolean)


3205
3206
3207
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3205

def verified_initialization_vector_crc32c
  @verified_initialization_vector_crc32c
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3213
3214
3215
3216
3217
3218
3219
3220
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3213

def update!(**args)
  @plaintext = args[:plaintext] if args.key?(:plaintext)
  @plaintext_crc32c = args[:plaintext_crc32c] if args.key?(:plaintext_crc32c)
  @protection_level = args[:protection_level] if args.key?(:protection_level)
  @verified_additional_authenticated_data_crc32c = args[:verified_additional_authenticated_data_crc32c] if args.key?(:verified_additional_authenticated_data_crc32c)
  @verified_ciphertext_crc32c = args[:verified_ciphertext_crc32c] if args.key?(:verified_ciphertext_crc32c)
  @verified_initialization_vector_crc32c = args[:verified_initialization_vector_crc32c] if args.key?(:verified_initialization_vector_crc32c)
end