Class: Google::Apis::CloudkmsV1::RequiredActionQuorumParameters
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::RequiredActionQuorumParameters
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
Parameters for an approval that has both required challenges and a quorum.
Instance Attribute Summary collapse
-
#approved_two_factor_public_key_pems ⇒ Array<String>
Output only.
-
#quorum_challenges ⇒ Array<Google::Apis::CloudkmsV1::Challenge>
Output only.
-
#required_approver_count ⇒ Fixnum
Output only.
-
#required_challenges ⇒ Array<Google::Apis::CloudkmsV1::Challenge>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RequiredActionQuorumParameters
constructor
A new instance of RequiredActionQuorumParameters.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RequiredActionQuorumParameters
Returns a new instance of RequiredActionQuorumParameters.
3533 3534 3535 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3533 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approved_two_factor_public_key_pems ⇒ Array<String>
Output only. The public keys associated with the 2FA keys that have already
approved the SingleTenantHsmInstanceProposal by signing the challenge.
Corresponds to the JSON property approvedTwoFactorPublicKeyPems
3513 3514 3515 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3513 def approved_two_factor_public_key_pems @approved_two_factor_public_key_pems end |
#quorum_challenges ⇒ Array<Google::Apis::CloudkmsV1::Challenge>
Output only. The challenges to be signed by 2FA keys for quorum auth. M of N
of these challenges are required to be signed to approve the operation.
Corresponds to the JSON property quorumChallenges
3519 3520 3521 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3519 def quorum_challenges @quorum_challenges end |
#required_approver_count ⇒ Fixnum
Output only. The required number of quorum approvers. This is the M value used
for M of N quorum auth. It is less than the number of public keys.
Corresponds to the JSON property requiredApproverCount
3525 3526 3527 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3525 def required_approver_count @required_approver_count end |
#required_challenges ⇒ Array<Google::Apis::CloudkmsV1::Challenge>
Output only. A list of specific challenges that must be signed. For some
operations, this will contain a single challenge.
Corresponds to the JSON property requiredChallenges
3531 3532 3533 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3531 def required_challenges @required_challenges end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3538 3539 3540 3541 3542 3543 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3538 def update!(**args) @approved_two_factor_public_key_pems = args[:approved_two_factor_public_key_pems] if args.key?(:approved_two_factor_public_key_pems) @quorum_challenges = args[:quorum_challenges] if args.key?(:quorum_challenges) @required_approver_count = args[:required_approver_count] if args.key?(:required_approver_count) @required_challenges = args[:required_challenges] if args.key?(:required_challenges) end |