Class: Google::Apis::CloudkmsV1::ShowEffectiveAutokeyConfigResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::ShowEffectiveAutokeyConfigResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
Response message for ShowEffectiveAutokeyConfig.
Instance Attribute Summary collapse
-
#key_project ⇒ String
Name of the key project configured in the ancestry of the project or folder.
-
#key_project_resolution_mode ⇒ String
The KeyProjectResolutionMode for the AutokeyConfig.
-
#source ⇒ Google::Apis::CloudkmsV1::Source
Source of the effective AutokeyConfig.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ShowEffectiveAutokeyConfigResponse
constructor
A new instance of ShowEffectiveAutokeyConfigResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ShowEffectiveAutokeyConfigResponse
Returns a new instance of ShowEffectiveAutokeyConfigResponse.
3882 3883 3884 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3882 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key_project ⇒ String
Name of the key project configured in the ancestry of the project or folder.
Corresponds to the JSON property keyProject
3870 3871 3872 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3870 def key_project @key_project end |
#key_project_resolution_mode ⇒ String
The KeyProjectResolutionMode for the AutokeyConfig.
Corresponds to the JSON property keyProjectResolutionMode
3875 3876 3877 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3875 def key_project_resolution_mode @key_project_resolution_mode end |
#source ⇒ Google::Apis::CloudkmsV1::Source
Source of the effective AutokeyConfig.
Corresponds to the JSON property source
3880 3881 3882 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3880 def source @source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3887 3888 3889 3890 3891 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3887 def update!(**args) @key_project = args[:key_project] if args.key?(:key_project) @key_project_resolution_mode = args[:key_project_resolution_mode] if args.key?(:key_project_resolution_mode) @source = args[:source] if args.key?(:source) end |