Class: Google::Apis::CloudkmsV1::ShowEffectiveKeyAccessJustificationsPolicyConfigResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::ShowEffectiveKeyAccessJustificationsPolicyConfigResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
Represents a response message for KeyAccessJustificationsConfig. ShowEffectiveKeyAccessJustificationsPolicyConfig.
Instance Attribute Summary collapse
-
#effective_kaj_policy ⇒ Google::Apis::CloudkmsV1::KeyAccessJustificationsPolicyConfig
Represents a singleton configuration for Key Access Justifications policies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ShowEffectiveKeyAccessJustificationsPolicyConfigResponse
constructor
A new instance of ShowEffectiveKeyAccessJustificationsPolicyConfigResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ShowEffectiveKeyAccessJustificationsPolicyConfigResponse
Returns a new instance of ShowEffectiveKeyAccessJustificationsPolicyConfigResponse.
3792 3793 3794 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3792 def initialize(**args) update!(**args) end |
Instance Attribute Details
#effective_kaj_policy ⇒ Google::Apis::CloudkmsV1::KeyAccessJustificationsPolicyConfig
Represents a singleton configuration for Key Access Justifications policies.
Corresponds to the JSON property effectiveKajPolicy
3790 3791 3792 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3790 def effective_kaj_policy @effective_kaj_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3797 3798 3799 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3797 def update!(**args) @effective_kaj_policy = args[:effective_kaj_policy] if args.key?(:effective_kaj_policy) end |