Class: Google::Apis::CloudkmsV1::AutokeyConfig
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::AutokeyConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
Cloud KMS Autokey configuration for a folder.
Instance Attribute Summary collapse
-
#etag ⇒ String
Optional.
-
#key_project ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutokeyConfig
constructor
A new instance of AutokeyConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutokeyConfig
Returns a new instance of AutokeyConfig.
417 418 419 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 417 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Optional. A checksum computed by the server based on the value of other fields.
This may be sent on update requests to ensure that the client has an up-to-
date value before proceeding. The request will be rejected with an ABORTED
error on a mismatched etag.
Corresponds to the JSON property etag
392 393 394 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 392 def etag @etag end |
#key_project ⇒ String
Optional. Name of the key project, e.g. projects/PROJECT_IDor `projects/`
PROJECT_NUMBER, where Cloud KMS Autokey will provision a new CryptoKey when
a KeyHandle is created. On UpdateAutokeyConfig, the caller will require
cloudkms.cryptoKeys.setIamPolicy permission on this key project. Once
configured, for Cloud KMS Autokey to function properly, this key project must
have the Cloud KMS API activated and the Cloud KMS Service Agent for this key
project must be granted the cloudkms.admin role (or pertinent permissions).
A request with an empty key project field will clear the configuration.
Corresponds to the JSON property keyProject
404 405 406 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 404 def key_project @key_project end |
#name ⇒ String
Identifier. Name of the AutokeyConfig resource, e.g. folders/FOLDER_NUMBER/
autokeyConfig
Corresponds to the JSON property name
410 411 412 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 410 def name @name end |
#state ⇒ String
Output only. The state for the AutokeyConfig.
Corresponds to the JSON property state
415 416 417 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 415 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
422 423 424 425 426 427 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 422 def update!(**args) @etag = args[:etag] if args.key?(:etag) @key_project = args[:key_project] if args.key?(:key_project) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) end |