Class: Google::Apis::CloudkmsV1::ChecksummedData
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::ChecksummedData
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
Data with integrity verification field.
Instance Attribute Summary collapse
-
#crc32c_checksum ⇒ Fixnum
Integrity verification field.
-
#data ⇒ String
Raw Data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChecksummedData
constructor
A new instance of ChecksummedData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChecksummedData
Returns a new instance of ChecksummedData.
719 720 721 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 719 def initialize(**args) update!(**args) end |
Instance Attribute Details
#crc32c_checksum ⇒ Fixnum
Integrity verification field. A CRC32C checksum of the returned
ChecksummedData.data. An integrity check of ChecksummedData.data can be
performed by computing the CRC32C checksum of ChecksummedData.data and
comparing your results to this field. Discard the response in case of non-
matching checksum values, and perform a limited number of retries. A
persistent mismatch may indicate an issue in your computation of the CRC32C
checksum. Note: This field is defined as int64 for reasons of compatibility
across different languages. However, it is a non-negative integer, which will
never exceed 2^32-1, and can be safely downconverted to uint32 in languages
that support this type.
Corresponds to the JSON property crc32cChecksum
711 712 713 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 711 def crc32c_checksum @crc32c_checksum end |
#data ⇒ String
Raw Data.
Corresponds to the JSON property data
NOTE: Values are automatically base64 encoded/decoded in the client library.
717 718 719 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 717 def data @data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
724 725 726 727 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 724 def update!(**args) @crc32c_checksum = args[:crc32c_checksum] if args.key?(:crc32c_checksum) @data = args[:data] if args.key?(:data) end |