Class: Google::Apis::CloudkmsV1::CryptoKeyVersion
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::CryptoKeyVersion
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
A CryptoKeyVersion represents an individual cryptographic key, and the associated key material. An ENABLED version can be used for cryptographic operations. For security reasons, the raw cryptographic key material represented by a CryptoKeyVersion can never be viewed or exported. It can only be used to encrypt, decrypt, or sign data when an authorized user or application invokes Cloud KMS.
Instance Attribute Summary collapse
-
#algorithm ⇒ String
Output only.
-
#attestation ⇒ Google::Apis::CloudkmsV1::KeyOperationAttestation
Contains an HSM-generated attestation about a key operation.
-
#create_time ⇒ String
Output only.
-
#destroy_event_time ⇒ String
Output only.
-
#destroy_time ⇒ String
Output only.
-
#external_destruction_failure_reason ⇒ String
Output only.
-
#external_protection_level_options ⇒ Google::Apis::CloudkmsV1::ExternalProtectionLevelOptions
ExternalProtectionLevelOptions stores a group of additional fields for configuring a CryptoKeyVersion that are specific to the EXTERNAL protection level and EXTERNAL_VPC protection levels.
-
#generate_time ⇒ String
Output only.
-
#generation_failure_reason ⇒ String
Output only.
-
#import_failure_reason ⇒ String
Output only.
-
#import_job ⇒ String
Output only.
-
#import_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#protection_level ⇒ String
Output only.
-
#reimport_eligible ⇒ Boolean
(also: #reimport_eligible?)
Output only.
-
#state ⇒ String
The current state of the CryptoKeyVersion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CryptoKeyVersion
constructor
A new instance of CryptoKeyVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CryptoKeyVersion
Returns a new instance of CryptoKeyVersion.
961 962 963 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 961 def initialize(**args) update!(**args) end |
Instance Attribute Details
#algorithm ⇒ String
Output only. The CryptoKeyVersionAlgorithm that this CryptoKeyVersion supports.
Corresponds to the JSON property algorithm
868 869 870 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 868 def algorithm @algorithm end |
#attestation ⇒ Google::Apis::CloudkmsV1::KeyOperationAttestation
Contains an HSM-generated attestation about a key operation. For more
information, see Verifying attestations.
Corresponds to the JSON property attestation
875 876 877 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 875 def attestation @attestation end |
#create_time ⇒ String
Output only. The time at which this CryptoKeyVersion was created.
Corresponds to the JSON property createTime
880 881 882 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 880 def create_time @create_time end |
#destroy_event_time ⇒ String
Output only. The time this CryptoKeyVersion's key material was destroyed. Only
present if state is DESTROYED.
Corresponds to the JSON property destroyEventTime
886 887 888 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 886 def destroy_event_time @destroy_event_time end |
#destroy_time ⇒ String
Output only. The time this CryptoKeyVersion's key material is scheduled for
destruction. Only present if state is DESTROY_SCHEDULED.
Corresponds to the JSON property destroyTime
892 893 894 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 892 def destroy_time @destroy_time end |
#external_destruction_failure_reason ⇒ String
Output only. The root cause of the most recent external destruction failure.
Only present if state is EXTERNAL_DESTRUCTION_FAILED.
Corresponds to the JSON property externalDestructionFailureReason
898 899 900 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 898 def external_destruction_failure_reason @external_destruction_failure_reason end |
#external_protection_level_options ⇒ Google::Apis::CloudkmsV1::ExternalProtectionLevelOptions
ExternalProtectionLevelOptions stores a group of additional fields for
configuring a CryptoKeyVersion that are specific to the EXTERNAL protection
level and EXTERNAL_VPC protection levels.
Corresponds to the JSON property externalProtectionLevelOptions
905 906 907 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 905 def @external_protection_level_options end |
#generate_time ⇒ String
Output only. The time this CryptoKeyVersion's key material was generated.
Corresponds to the JSON property generateTime
910 911 912 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 910 def generate_time @generate_time end |
#generation_failure_reason ⇒ String
Output only. The root cause of the most recent generation failure. Only
present if state is GENERATION_FAILED.
Corresponds to the JSON property generationFailureReason
916 917 918 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 916 def generation_failure_reason @generation_failure_reason end |
#import_failure_reason ⇒ String
Output only. The root cause of the most recent import failure. Only present if
state is IMPORT_FAILED.
Corresponds to the JSON property importFailureReason
922 923 924 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 922 def import_failure_reason @import_failure_reason end |
#import_job ⇒ String
Output only. The name of the ImportJob used in the most recent import of this
CryptoKeyVersion. Only present if the underlying key material was imported.
Corresponds to the JSON property importJob
928 929 930 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 928 def import_job @import_job end |
#import_time ⇒ String
Output only. The time at which this CryptoKeyVersion's key material was most
recently imported.
Corresponds to the JSON property importTime
934 935 936 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 934 def import_time @import_time end |
#name ⇒ String
Output only. The resource name for this CryptoKeyVersion in the format
projects/*/locations/*/keyRings/*/cryptoKeys/*/cryptoKeyVersions/*.
Corresponds to the JSON property name
940 941 942 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 940 def name @name end |
#protection_level ⇒ String
Output only. The ProtectionLevel describing how crypto operations are
performed with this CryptoKeyVersion.
Corresponds to the JSON property protectionLevel
946 947 948 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 946 def protection_level @protection_level end |
#reimport_eligible ⇒ Boolean Also known as: reimport_eligible?
Output only. Whether or not this key version is eligible for reimport, by
being specified as a target in ImportCryptoKeyVersionRequest.
crypto_key_version.
Corresponds to the JSON property reimportEligible
953 954 955 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 953 def reimport_eligible @reimport_eligible end |
#state ⇒ String
The current state of the CryptoKeyVersion.
Corresponds to the JSON property state
959 960 961 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 959 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 966 def update!(**args) @algorithm = args[:algorithm] if args.key?(:algorithm) @attestation = args[:attestation] if args.key?(:attestation) @create_time = args[:create_time] if args.key?(:create_time) @destroy_event_time = args[:destroy_event_time] if args.key?(:destroy_event_time) @destroy_time = args[:destroy_time] if args.key?(:destroy_time) @external_destruction_failure_reason = args[:external_destruction_failure_reason] if args.key?(:external_destruction_failure_reason) @external_protection_level_options = args[:external_protection_level_options] if args.key?(:external_protection_level_options) @generate_time = args[:generate_time] if args.key?(:generate_time) @generation_failure_reason = args[:generation_failure_reason] if args.key?(:generation_failure_reason) @import_failure_reason = args[:import_failure_reason] if args.key?(:import_failure_reason) @import_job = args[:import_job] if args.key?(:import_job) @import_time = args[:import_time] if args.key?(:import_time) @name = args[:name] if args.key?(:name) @protection_level = args[:protection_level] if args.key?(:protection_level) @reimport_eligible = args[:reimport_eligible] if args.key?(:reimport_eligible) @state = args[:state] if args.key?(:state) end |