Class: Google::Apis::CloudkmsV1::CryptoKeyVersion

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

A CryptoKeyVersion represents an individual cryptographic key, and the associated key material. An ENABLED version can be used for cryptographic operations. For security reasons, the raw cryptographic key material represented by a CryptoKeyVersion can never be viewed or exported. It can only be used to encrypt, decrypt, or sign data when an authorized user or application invokes Cloud KMS.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CryptoKeyVersion

Returns a new instance of CryptoKeyVersion.



952
953
954
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 952

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#algorithmString

Output only. The CryptoKeyVersionAlgorithm that this CryptoKeyVersion supports. Corresponds to the JSON property algorithm

Returns:

  • (String)


859
860
861
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 859

def algorithm
  @algorithm
end

#attestationGoogle::Apis::CloudkmsV1::KeyOperationAttestation

Contains an HSM-generated attestation about a key operation. For more information, see Verifying attestations. Corresponds to the JSON property attestation



866
867
868
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 866

def attestation
  @attestation
end

#create_timeString

Output only. The time at which this CryptoKeyVersion was created. Corresponds to the JSON property createTime

Returns:

  • (String)


871
872
873
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 871

def create_time
  @create_time
end

#destroy_event_timeString

Output only. The time this CryptoKeyVersion's key material was destroyed. Only present if state is DESTROYED. Corresponds to the JSON property destroyEventTime

Returns:

  • (String)


877
878
879
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 877

def destroy_event_time
  @destroy_event_time
end

#destroy_timeString

Output only. The time this CryptoKeyVersion's key material is scheduled for destruction. Only present if state is DESTROY_SCHEDULED. Corresponds to the JSON property destroyTime

Returns:

  • (String)


883
884
885
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 883

def destroy_time
  @destroy_time
end

#external_destruction_failure_reasonString

Output only. The root cause of the most recent external destruction failure. Only present if state is EXTERNAL_DESTRUCTION_FAILED. Corresponds to the JSON property externalDestructionFailureReason

Returns:

  • (String)


889
890
891
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 889

def external_destruction_failure_reason
  @external_destruction_failure_reason
end

#external_protection_level_optionsGoogle::Apis::CloudkmsV1::ExternalProtectionLevelOptions

ExternalProtectionLevelOptions stores a group of additional fields for configuring a CryptoKeyVersion that are specific to the EXTERNAL protection level and EXTERNAL_VPC protection levels. Corresponds to the JSON property externalProtectionLevelOptions



896
897
898
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 896

def external_protection_level_options
  @external_protection_level_options
end

#generate_timeString

Output only. The time this CryptoKeyVersion's key material was generated. Corresponds to the JSON property generateTime

Returns:

  • (String)


901
902
903
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 901

def generate_time
  @generate_time
end

#generation_failure_reasonString

Output only. The root cause of the most recent generation failure. Only present if state is GENERATION_FAILED. Corresponds to the JSON property generationFailureReason

Returns:

  • (String)


907
908
909
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 907

def generation_failure_reason
  @generation_failure_reason
end

#import_failure_reasonString

Output only. The root cause of the most recent import failure. Only present if state is IMPORT_FAILED. Corresponds to the JSON property importFailureReason

Returns:

  • (String)


913
914
915
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 913

def import_failure_reason
  @import_failure_reason
end

#import_jobString

Output only. The name of the ImportJob used in the most recent import of this CryptoKeyVersion. Only present if the underlying key material was imported. Corresponds to the JSON property importJob

Returns:

  • (String)


919
920
921
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 919

def import_job
  @import_job
end

#import_timeString

Output only. The time at which this CryptoKeyVersion's key material was most recently imported. Corresponds to the JSON property importTime

Returns:

  • (String)


925
926
927
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 925

def import_time
  @import_time
end

#nameString

Output only. The resource name for this CryptoKeyVersion in the format projects/*/locations/*/keyRings/*/cryptoKeys/*/cryptoKeyVersions/*. Corresponds to the JSON property name

Returns:

  • (String)


931
932
933
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 931

def name
  @name
end

#protection_levelString

Output only. The ProtectionLevel describing how crypto operations are performed with this CryptoKeyVersion. Corresponds to the JSON property protectionLevel

Returns:

  • (String)


937
938
939
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 937

def protection_level
  @protection_level
end

#reimport_eligibleBoolean Also known as: reimport_eligible?

Output only. Whether or not this key version is eligible for reimport, by being specified as a target in ImportCryptoKeyVersionRequest. crypto_key_version. Corresponds to the JSON property reimportEligible

Returns:

  • (Boolean)


944
945
946
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 944

def reimport_eligible
  @reimport_eligible
end

#stateString

The current state of the CryptoKeyVersion. Corresponds to the JSON property state

Returns:

  • (String)


950
951
952
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 950

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 957

def update!(**args)
  @algorithm = args[:algorithm] if args.key?(:algorithm)
  @attestation = args[:attestation] if args.key?(:attestation)
  @create_time = args[:create_time] if args.key?(:create_time)
  @destroy_event_time = args[:destroy_event_time] if args.key?(:destroy_event_time)
  @destroy_time = args[:destroy_time] if args.key?(:destroy_time)
  @external_destruction_failure_reason = args[:external_destruction_failure_reason] if args.key?(:external_destruction_failure_reason)
  @external_protection_level_options = args[:external_protection_level_options] if args.key?(:external_protection_level_options)
  @generate_time = args[:generate_time] if args.key?(:generate_time)
  @generation_failure_reason = args[:generation_failure_reason] if args.key?(:generation_failure_reason)
  @import_failure_reason = args[:import_failure_reason] if args.key?(:import_failure_reason)
  @import_job = args[:import_job] if args.key?(:import_job)
  @import_time = args[:import_time] if args.key?(:import_time)
  @name = args[:name] if args.key?(:name)
  @protection_level = args[:protection_level] if args.key?(:protection_level)
  @reimport_eligible = args[:reimport_eligible] if args.key?(:reimport_eligible)
  @state = args[:state] if args.key?(:state)
end