Class: Google::Apis::CloudkmsV1::DecapsulateResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::DecapsulateResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
Response message for KeyManagementService.Decapsulate.
Instance Attribute Summary collapse
-
#name ⇒ String
The resource name of the CryptoKeyVersion used for decapsulation.
-
#protection_level ⇒ String
The ProtectionLevel of the CryptoKeyVersion used in decapsulation.
-
#shared_secret ⇒ String
The decapsulated shared_secret originally encapsulated with the matching public key.
-
#shared_secret_crc32c ⇒ Fixnum
Integrity verification field.
-
#verified_ciphertext_crc32c ⇒ Boolean
(also: #verified_ciphertext_crc32c?)
Integrity verification field.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DecapsulateResponse
constructor
A new instance of DecapsulateResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DecapsulateResponse
Returns a new instance of DecapsulateResponse.
1094 1095 1096 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1094 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The resource name of the CryptoKeyVersion used for decapsulation. Check this
field to verify that the intended resource was used for decapsulation.
Corresponds to the JSON property name
1052 1053 1054 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1052 def name @name end |
#protection_level ⇒ String
The ProtectionLevel of the CryptoKeyVersion used in decapsulation.
Corresponds to the JSON property protectionLevel
1057 1058 1059 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1057 def protection_level @protection_level end |
#shared_secret ⇒ String
The decapsulated shared_secret originally encapsulated with the matching
public key.
Corresponds to the JSON property sharedSecret
NOTE: Values are automatically base64 encoded/decoded in the client library.
1064 1065 1066 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1064 def shared_secret @shared_secret end |
#shared_secret_crc32c ⇒ Fixnum
Integrity verification field. A CRC32C checksum of the returned
DecapsulateResponse.shared_secret. An integrity check of DecapsulateResponse.
shared_secret can be performed by computing the CRC32C checksum of
DecapsulateResponse.shared_secret and comparing your results to this field.
Discard the response in case of non-matching checksum values, and perform a
limited number of retries. A persistent mismatch may indicate an issue in your
computation of the CRC32C checksum. Note: receiving this response message
indicates that KeyManagementService is able to successfully decrypt the
ciphertext. Note: This field is defined as int64 for reasons of compatibility
across different languages. However, it is a non-negative integer, which will
never exceed 2^32-1, and can be safely downconverted to uint32 in languages
that support this type.
Corresponds to the JSON property sharedSecretCrc32c
1080 1081 1082 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1080 def shared_secret_crc32c @shared_secret_crc32c end |
#verified_ciphertext_crc32c ⇒ Boolean Also known as: verified_ciphertext_crc32c?
Integrity verification field. A flag indicating whether DecapsulateRequest.
ciphertext_crc32c was received by KeyManagementService and used for the
integrity verification of the ciphertext. A false value of this field
indicates either that DecapsulateRequest.ciphertext_crc32c was left unset or
that it was not delivered to KeyManagementService. If you've set
DecapsulateRequest.ciphertext_crc32c but this field is still false, discard
the response and perform a limited number of retries.
Corresponds to the JSON property verifiedCiphertextCrc32c
1091 1092 1093 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1091 def verified_ciphertext_crc32c @verified_ciphertext_crc32c end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1099 def update!(**args) @name = args[:name] if args.key?(:name) @protection_level = args[:protection_level] if args.key?(:protection_level) @shared_secret = args[:shared_secret] if args.key?(:shared_secret) @shared_secret_crc32c = args[:shared_secret_crc32c] if args.key?(:shared_secret_crc32c) @verified_ciphertext_crc32c = args[:verified_ciphertext_crc32c] if args.key?(:verified_ciphertext_crc32c) end |