Class: Google::Apis::CloudkmsV1::DecryptResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

Response message for KeyManagementService.Decrypt.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DecryptResponse

Returns a new instance of DecryptResponse.



1216
1217
1218
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1216

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#plaintextString

The decrypted data originally supplied in EncryptRequest.plaintext. Corresponds to the JSON property plaintext NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1187
1188
1189
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1187

def plaintext
  @plaintext
end

#plaintext_crc32cFixnum

Integrity verification field. A CRC32C checksum of the returned DecryptResponse.plaintext. An integrity check of DecryptResponse.plaintext can be performed by computing the CRC32C checksum of DecryptResponse.plaintext and comparing your results to this field. Discard the response in case of non- matching checksum values, and perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: receiving this response message indicates that KeyManagementService is able to successfully decrypt the ciphertext. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32- 1, and can be safely downconverted to uint32 in languages that support this type. Corresponds to the JSON property plaintextCrc32c

Returns:

  • (Fixnum)


1203
1204
1205
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1203

def plaintext_crc32c
  @plaintext_crc32c
end

#protection_levelString

The ProtectionLevel of the CryptoKeyVersion used in decryption. Corresponds to the JSON property protectionLevel

Returns:

  • (String)


1208
1209
1210
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1208

def protection_level
  @protection_level
end

#used_primaryBoolean Also known as: used_primary?

Whether the Decryption was performed using the primary key version. Corresponds to the JSON property usedPrimary

Returns:

  • (Boolean)


1213
1214
1215
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1213

def used_primary
  @used_primary
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1221
1222
1223
1224
1225
1226
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1221

def update!(**args)
  @plaintext = args[:plaintext] if args.key?(:plaintext)
  @plaintext_crc32c = args[:plaintext_crc32c] if args.key?(:plaintext_crc32c)
  @protection_level = args[:protection_level] if args.key?(:protection_level)
  @used_primary = args[:used_primary] if args.key?(:used_primary)
end