Class: Google::Apis::CloudkmsV1::EncryptResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::EncryptResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
Response message for KeyManagementService.Encrypt.
Instance Attribute Summary collapse
-
#ciphertext ⇒ String
The encrypted data.
-
#ciphertext_crc32c ⇒ Fixnum
Integrity verification field.
-
#name ⇒ String
The resource name of the CryptoKeyVersion used in encryption.
-
#protection_level ⇒ String
The ProtectionLevel of the CryptoKeyVersion used in encryption.
-
#verified_additional_authenticated_data_crc32c ⇒ Boolean
(also: #verified_additional_authenticated_data_crc32c?)
Integrity verification field.
-
#verified_plaintext_crc32c ⇒ Boolean
(also: #verified_plaintext_crc32c?)
Integrity verification field.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EncryptResponse
constructor
A new instance of EncryptResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EncryptResponse
Returns a new instance of EncryptResponse.
1540 1541 1542 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1540 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ciphertext ⇒ String
The encrypted data.
Corresponds to the JSON property ciphertext
NOTE: Values are automatically base64 encoded/decoded in the client library.
1489 1490 1491 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1489 def ciphertext @ciphertext end |
#ciphertext_crc32c ⇒ Fixnum
Integrity verification field. A CRC32C checksum of the returned
EncryptResponse.ciphertext. An integrity check of EncryptResponse.ciphertext
can be performed by computing the CRC32C checksum of EncryptResponse.
ciphertext and comparing your results to this field. Discard the response in
case of non-matching checksum values, and perform a limited number of retries.
A persistent mismatch may indicate an issue in your computation of the CRC32C
checksum. Note: This field is defined as int64 for reasons of compatibility
across different languages. However, it is a non-negative integer, which will
never exceed 2^32-1, and can be safely downconverted to uint32 in languages
that support this type.
Corresponds to the JSON property ciphertextCrc32c
1503 1504 1505 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1503 def ciphertext_crc32c @ciphertext_crc32c end |
#name ⇒ String
The resource name of the CryptoKeyVersion used in encryption. Check this field
to verify that the intended resource was used for encryption.
Corresponds to the JSON property name
1509 1510 1511 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1509 def name @name end |
#protection_level ⇒ String
The ProtectionLevel of the CryptoKeyVersion used in encryption.
Corresponds to the JSON property protectionLevel
1514 1515 1516 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1514 def protection_level @protection_level end |
#verified_additional_authenticated_data_crc32c ⇒ Boolean Also known as: verified_additional_authenticated_data_crc32c?
Integrity verification field. A flag indicating whether EncryptRequest.
additional_authenticated_data_crc32c was received by KeyManagementService and
used for the integrity verification of the AAD. A false value of this field
indicates either that EncryptRequest.additional_authenticated_data_crc32c was
left unset or that it was not delivered to KeyManagementService. If you've set
EncryptRequest.additional_authenticated_data_crc32c but this field is still
false, discard the response and perform a limited number of retries.
Corresponds to the JSON property verifiedAdditionalAuthenticatedDataCrc32c
1525 1526 1527 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1525 def verified_additional_authenticated_data_crc32c @verified_additional_authenticated_data_crc32c end |
#verified_plaintext_crc32c ⇒ Boolean Also known as: verified_plaintext_crc32c?
Integrity verification field. A flag indicating whether EncryptRequest.
plaintext_crc32c was received by KeyManagementService and used for the
integrity verification of the plaintext. A false value of this field indicates
either that EncryptRequest.plaintext_crc32c was left unset or that it was not
delivered to KeyManagementService. If you've set EncryptRequest.
plaintext_crc32c but this field is still false, discard the response and
perform a limited number of retries.
Corresponds to the JSON property verifiedPlaintextCrc32c
1537 1538 1539 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1537 def verified_plaintext_crc32c @verified_plaintext_crc32c end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1545 1546 1547 1548 1549 1550 1551 1552 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1545 def update!(**args) @ciphertext = args[:ciphertext] if args.key?(:ciphertext) @ciphertext_crc32c = args[:ciphertext_crc32c] if args.key?(:ciphertext_crc32c) @name = args[:name] if args.key?(:name) @protection_level = args[:protection_level] if args.key?(:protection_level) @verified_additional_authenticated_data_crc32c = args[:verified_additional_authenticated_data_crc32c] if args.key?(:verified_additional_authenticated_data_crc32c) @verified_plaintext_crc32c = args[:verified_plaintext_crc32c] if args.key?(:verified_plaintext_crc32c) end |