Class: Google::Apis::CloudkmsV1::ExternalProtectionLevelOptions
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::ExternalProtectionLevelOptions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
ExternalProtectionLevelOptions stores a group of additional fields for configuring a CryptoKeyVersion that are specific to the EXTERNAL protection level and EXTERNAL_VPC protection levels.
Instance Attribute Summary collapse
-
#ekm_connection_backend_override ⇒ String
Optional.
-
#ekm_connection_key_path ⇒ String
Optional.
-
#external_key_uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternalProtectionLevelOptions
constructor
A new instance of ExternalProtectionLevelOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternalProtectionLevelOptions
Returns a new instance of ExternalProtectionLevelOptions.
1725 1726 1727 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1725 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ekm_connection_backend_override ⇒ String
Optional. The resource name of the backend environment where the key material
of CryptoKeyVersions is associated with. Setting this field overrides the
CryptoKeyBackend. This field may be set when CryptoKeyVersions is set to
EXTERNAL_VPC. Format: projects/*/locations/*/ekmConnections/*.
Corresponds to the JSON property ekmConnectionBackendOverride
1710 1711 1712 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1710 def ekm_connection_backend_override @ekm_connection_backend_override end |
#ekm_connection_key_path ⇒ String
Optional. The path to the external key material on the EKM when using
EkmConnection e.g., "v0/my/key". Set this field instead of external_key_uri
when using an EkmConnection.
Corresponds to the JSON property ekmConnectionKeyPath
1717 1718 1719 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1717 def ekm_connection_key_path @ekm_connection_key_path end |
#external_key_uri ⇒ String
Optional. The URI for an external resource that this CryptoKeyVersion
represents.
Corresponds to the JSON property externalKeyUri
1723 1724 1725 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1723 def external_key_uri @external_key_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1730 1731 1732 1733 1734 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1730 def update!(**args) @ekm_connection_backend_override = args[:ekm_connection_backend_override] if args.key?(:ekm_connection_backend_override) @ekm_connection_key_path = args[:ekm_connection_key_path] if args.key?(:ekm_connection_key_path) @external_key_uri = args[:external_key_uri] if args.key?(:external_key_uri) end |