Class: Google::Apis::CloudkmsV1::ImportCryptoKeyVersionRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::ImportCryptoKeyVersionRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
Request message for KeyManagementService.ImportCryptoKeyVersion.
Instance Attribute Summary collapse
-
#algorithm ⇒ String
Required.
-
#crypto_key_version ⇒ String
Optional.
-
#import_job ⇒ String
Required.
-
#rsa_aes_wrapped_key ⇒ String
Optional.
-
#wrapped_key ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImportCryptoKeyVersionRequest
constructor
A new instance of ImportCryptoKeyVersionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImportCryptoKeyVersionRequest
Returns a new instance of ImportCryptoKeyVersionRequest.
1785 1786 1787 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1785 def initialize(**args) update!(**args) end |
Instance Attribute Details
#algorithm ⇒ String
Required. The algorithm of the key being imported. This does not need to match
the version_template of the CryptoKey this version imports into.
Corresponds to the JSON property algorithm
1737 1738 1739 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1737 def algorithm @algorithm end |
#crypto_key_version ⇒ String
Optional. The optional name of an existing CryptoKeyVersion to target for an
import operation. If this field is not present, a new CryptoKeyVersion
containing the supplied key material is created. If this field is present, the
supplied key material is imported into the existing CryptoKeyVersion. To
import into an existing CryptoKeyVersion, the CryptoKeyVersion must be a child
of ImportCryptoKeyVersionRequest.parent, have been previously created via
ImportCryptoKeyVersion, and be in DESTROYED or IMPORT_FAILED state. The key
material and algorithm must match the previous CryptoKeyVersion exactly if the
CryptoKeyVersion has ever contained key material.
Corresponds to the JSON property cryptoKeyVersion
1750 1751 1752 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1750 def crypto_key_version @crypto_key_version end |
#import_job ⇒ String
Required. The name of the ImportJob that was used to wrap this key material.
Corresponds to the JSON property importJob
1755 1756 1757 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1755 def import_job @import_job end |
#rsa_aes_wrapped_key ⇒ String
Optional. This field has the same meaning as wrapped_key. Prefer to use that
field in new work. Either that field or this field (but not both) must be
specified.
Corresponds to the JSON property rsaAesWrappedKey
NOTE: Values are automatically base64 encoded/decoded in the client library.
1763 1764 1765 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1763 def rsa_aes_wrapped_key @rsa_aes_wrapped_key end |
#wrapped_key ⇒ String
Optional. The wrapped key material to import. Before wrapping, key material
must be formatted. If importing symmetric key material, the expected key
material format is plain bytes. If importing asymmetric key material, the
expected key material format is PKCS#8-encoded DER (the PrivateKeyInfo
structure from RFC 5208). When wrapping with import methods (
RSA_OAEP_3072_SHA1_AES_256 or RSA_OAEP_4096_SHA1_AES_256 or
RSA_OAEP_3072_SHA256_AES_256 or RSA_OAEP_4096_SHA256_AES_256), this field must
contain the concatenation of: 1. An ephemeral AES-256 wrapping key wrapped
with the public_key using RSAES-OAEP with SHA-1/SHA-256, MGF1 with SHA-1/SHA-
256, and an empty label. 2. The formatted key to be imported, wrapped with the
ephemeral AES-256 key using AES-KWP (RFC 5649). This format is the same as the
format produced by PKCS#11 mechanism CKM_RSA_AES_KEY_WRAP. When wrapping with
import methods (RSA_OAEP_3072_SHA256 or RSA_OAEP_4096_SHA256), this field must
contain the formatted key to be imported, wrapped with the public_key using
RSAES-OAEP with SHA-256, MGF1 with SHA-256, and an empty label.
Corresponds to the JSON property wrappedKey
NOTE: Values are automatically base64 encoded/decoded in the client library.
1783 1784 1785 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1783 def wrapped_key @wrapped_key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1790 1791 1792 1793 1794 1795 1796 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1790 def update!(**args) @algorithm = args[:algorithm] if args.key?(:algorithm) @crypto_key_version = args[:crypto_key_version] if args.key?(:crypto_key_version) @import_job = args[:import_job] if args.key?(:import_job) @rsa_aes_wrapped_key = args[:rsa_aes_wrapped_key] if args.key?(:rsa_aes_wrapped_key) @wrapped_key = args[:wrapped_key] if args.key?(:wrapped_key) end |