Class: Google::Apis::CloudkmsV1::KeyAccessJustificationsPolicyConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

Represents a singleton configuration for Key Access Justifications policies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KeyAccessJustificationsPolicyConfig

Returns a new instance of KeyAccessJustificationsPolicyConfig.



1996
1997
1998
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1996

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_key_access_justification_policyGoogle::Apis::CloudkmsV1::KeyAccessJustificationsPolicy

A KeyAccessJustificationsPolicy specifies zero or more allowed AccessReason values for encrypt, decrypt, and sign operations on a CryptoKey or KeyAccessJustificationsPolicyConfig (the default Key Access Justifications policy). Corresponds to the JSON property defaultKeyAccessJustificationPolicy



1978
1979
1980
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1978

def default_key_access_justification_policy
  @default_key_access_justification_policy
end

#default_policy_availableBoolean Also known as: default_policy_available?

Output only. Indicates whether this parent resource is available to default policy feature. Please consult the prerequisite of default policy feature for more details. Corresponds to the JSON property defaultPolicyAvailable

Returns:

  • (Boolean)


1986
1987
1988
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1986

def default_policy_available
  @default_policy_available
end

#nameString

Identifier. Represents the resource name for this KeyAccessJustificationsPolicyConfig in the format of "organizations|folders| projects/*/kajPolicyConfig". Corresponds to the JSON property name

Returns:

  • (String)


1994
1995
1996
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1994

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2001
2002
2003
2004
2005
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2001

def update!(**args)
  @default_key_access_justification_policy = args[:default_key_access_justification_policy] if args.key?(:default_key_access_justification_policy)
  @default_policy_available = args[:default_policy_available] if args.key?(:default_policy_available)
  @name = args[:name] if args.key?(:name)
end