Class: Google::Apis::CloudkmsV1::KeyAccessJustificationsPolicyConfig
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::KeyAccessJustificationsPolicyConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
A singleton configuration for Key Access Justifications policies.
Instance Attribute Summary collapse
-
#default_key_access_justification_policy ⇒ Google::Apis::CloudkmsV1::KeyAccessJustificationsPolicy
A KeyAccessJustificationsPolicy specifies zero or more allowed AccessReason values for encrypt, decrypt, and sign operations on a CryptoKey.
-
#name ⇒ String
Identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KeyAccessJustificationsPolicyConfig
constructor
A new instance of KeyAccessJustificationsPolicyConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ KeyAccessJustificationsPolicyConfig
Returns a new instance of KeyAccessJustificationsPolicyConfig.
1972 1973 1974 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1972 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_key_access_justification_policy ⇒ Google::Apis::CloudkmsV1::KeyAccessJustificationsPolicy
A KeyAccessJustificationsPolicy specifies zero or more allowed AccessReason
values for encrypt, decrypt, and sign operations on a CryptoKey.
Corresponds to the JSON property defaultKeyAccessJustificationPolicy
1964 1965 1966 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1964 def default_key_access_justification_policy @default_key_access_justification_policy end |
#name ⇒ String
Identifier. The resource name for this KeyAccessJustificationsPolicyConfig in
the format of "organizations|folders|projects/*/kajPolicyConfig".
Corresponds to the JSON property name
1970 1971 1972 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1970 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1977 1978 1979 1980 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1977 def update!(**args) @default_key_access_justification_policy = args[:default_key_access_justification_policy] if args.key?(:default_key_access_justification_policy) @name = args[:name] if args.key?(:name) end |