Class: Google::Apis::CloudkmsV1::KeyAccessJustificationsPolicyConfig
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::KeyAccessJustificationsPolicyConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
A singleton configuration for Key Access Justifications policies.
Instance Attribute Summary collapse
-
#default_key_access_justification_policy ⇒ Google::Apis::CloudkmsV1::KeyAccessJustificationsPolicy
A KeyAccessJustificationsPolicy specifies zero or more allowed AccessReason values for encrypt, decrypt, and sign operations on a CryptoKey.
-
#name ⇒ String
Identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KeyAccessJustificationsPolicyConfig
constructor
A new instance of KeyAccessJustificationsPolicyConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ KeyAccessJustificationsPolicyConfig
Returns a new instance of KeyAccessJustificationsPolicyConfig.
1955 1956 1957 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1955 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_key_access_justification_policy ⇒ Google::Apis::CloudkmsV1::KeyAccessJustificationsPolicy
A KeyAccessJustificationsPolicy specifies zero or more allowed AccessReason
values for encrypt, decrypt, and sign operations on a CryptoKey.
Corresponds to the JSON property defaultKeyAccessJustificationPolicy
1947 1948 1949 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1947 def default_key_access_justification_policy @default_key_access_justification_policy end |
#name ⇒ String
Identifier. The resource name for this KeyAccessJustificationsPolicyConfig in
the format of "organizations|folders|projects/*/kajPolicyConfig".
Corresponds to the JSON property name
1953 1954 1955 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1953 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1960 1961 1962 1963 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 1960 def update!(**args) @default_key_access_justification_policy = args[:default_key_access_justification_policy] if args.key?(:default_key_access_justification_policy) @name = args[:name] if args.key?(:name) end |