Class: Google::Apis::CloudkmsV1::MacVerifyRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

Request message for KeyManagementService.MacVerify.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MacVerifyRequest

Returns a new instance of MacVerifyRequest.



2650
2651
2652
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataString

Required. The data used previously as a MacSignRequest.data to generate the MAC tag. Corresponds to the JSON property data NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


2612
2613
2614
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2612

def data
  @data
end

#data_crc32cFixnum

Optional. An optional CRC32C checksum of the MacVerifyRequest.data. If specified, KeyManagementService will verify the integrity of the received MacVerifyRequest.data using this checksum. KeyManagementService will report an error if the checksum verification fails. If you receive a checksum error, your client should verify that CRC32C(MacVerifyRequest.data) is equal to MacVerifyRequest.data_crc32c, and if so, perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type. Corresponds to the JSON property dataCrc32c

Returns:

  • (Fixnum)


2627
2628
2629
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2627

def data_crc32c
  @data_crc32c
end

#macString

Required. The signature to verify. Corresponds to the JSON property mac NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


2633
2634
2635
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2633

def mac
  @mac
end

#mac_crc32cFixnum

Optional. An optional CRC32C checksum of the MacVerifyRequest.mac. If specified, KeyManagementService will verify the integrity of the received MacVerifyRequest.mac using this checksum. KeyManagementService will report an error if the checksum verification fails. If you receive a checksum error, your client should verify that CRC32C(MacVerifyRequest.mac) is equal to MacVerifyRequest.mac_crc32c, and if so, perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type. Corresponds to the JSON property macCrc32c

Returns:

  • (Fixnum)


2648
2649
2650
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2648

def mac_crc32c
  @mac_crc32c
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2655
2656
2657
2658
2659
2660
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2655

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @data_crc32c = args[:data_crc32c] if args.key?(:data_crc32c)
  @mac = args[:mac] if args.key?(:mac)
  @mac_crc32c = args[:mac_crc32c] if args.key?(:mac_crc32c)
end