Class: Google::Apis::CloudkmsV1::MacVerifyRequest
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::MacVerifyRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
Request message for KeyManagementService.MacVerify.
Instance Attribute Summary collapse
-
#data ⇒ String
Required.
-
#data_crc32c ⇒ Fixnum
Optional.
-
#mac ⇒ String
Required.
-
#mac_crc32c ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MacVerifyRequest
constructor
A new instance of MacVerifyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MacVerifyRequest
Returns a new instance of MacVerifyRequest.
2583 2584 2585 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2583 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ String
Required. The data used previously as a MacSignRequest.data to generate the
MAC tag.
Corresponds to the JSON property data
NOTE: Values are automatically base64 encoded/decoded in the client library.
2545 2546 2547 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2545 def data @data end |
#data_crc32c ⇒ Fixnum
Optional. An optional CRC32C checksum of the MacVerifyRequest.data. If
specified, KeyManagementService will verify the integrity of the received
MacVerifyRequest.data using this checksum. KeyManagementService will report an
error if the checksum verification fails. If you receive a checksum error,
your client should verify that CRC32C(MacVerifyRequest.data) is equal to
MacVerifyRequest.data_crc32c, and if so, perform a limited number of retries.
A persistent mismatch may indicate an issue in your computation of the CRC32C
checksum. Note: This field is defined as int64 for reasons of compatibility
across different languages. However, it is a non-negative integer, which will
never exceed 2^32-1, and can be safely downconverted to uint32 in languages
that support this type.
Corresponds to the JSON property dataCrc32c
2560 2561 2562 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2560 def data_crc32c @data_crc32c end |
#mac ⇒ String
Required. The signature to verify.
Corresponds to the JSON property mac
NOTE: Values are automatically base64 encoded/decoded in the client library.
2566 2567 2568 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2566 def mac @mac end |
#mac_crc32c ⇒ Fixnum
Optional. An optional CRC32C checksum of the MacVerifyRequest.mac. If
specified, KeyManagementService will verify the integrity of the received
MacVerifyRequest.mac using this checksum. KeyManagementService will report an
error if the checksum verification fails. If you receive a checksum error,
your client should verify that CRC32C(MacVerifyRequest.mac) is equal to
MacVerifyRequest.mac_crc32c, and if so, perform a limited number of retries. A
persistent mismatch may indicate an issue in your computation of the CRC32C
checksum. Note: This field is defined as int64 for reasons of compatibility
across different languages. However, it is a non-negative integer, which will
never exceed 2^32-1, and can be safely downconverted to uint32 in languages
that support this type.
Corresponds to the JSON property macCrc32c
2581 2582 2583 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2581 def mac_crc32c @mac_crc32c end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2588 2589 2590 2591 2592 2593 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2588 def update!(**args) @data = args[:data] if args.key?(:data) @data_crc32c = args[:data_crc32c] if args.key?(:data_crc32c) @mac = args[:mac] if args.key?(:mac) @mac_crc32c = args[:mac_crc32c] if args.key?(:mac_crc32c) end |