Class: Google::Apis::CloudkmsV1::MacVerifyResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::MacVerifyResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
Response message for KeyManagementService.MacVerify.
Instance Attribute Summary collapse
-
#name ⇒ String
The resource name of the CryptoKeyVersion used for verification.
-
#protection_level ⇒ String
The ProtectionLevel of the CryptoKeyVersion used for verification.
-
#success ⇒ Boolean
(also: #success?)
This field indicates whether or not the verification operation for MacVerifyRequest.mac over MacVerifyRequest.data was successful.
-
#verified_data_crc32c ⇒ Boolean
(also: #verified_data_crc32c?)
Integrity verification field.
-
#verified_mac_crc32c ⇒ Boolean
(also: #verified_mac_crc32c?)
Integrity verification field.
-
#verified_success_integrity ⇒ Boolean
(also: #verified_success_integrity?)
Integrity verification field.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MacVerifyResponse
constructor
A new instance of MacVerifyResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MacVerifyResponse
Returns a new instance of MacVerifyResponse.
2717 2718 2719 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2717 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The resource name of the CryptoKeyVersion used for verification. Check this
field to verify that the intended resource was used for verification.
Corresponds to the JSON property name
2671 2672 2673 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2671 def name @name end |
#protection_level ⇒ String
The ProtectionLevel of the CryptoKeyVersion used for verification.
Corresponds to the JSON property protectionLevel
2676 2677 2678 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2676 def protection_level @protection_level end |
#success ⇒ Boolean Also known as: success?
This field indicates whether or not the verification operation for
MacVerifyRequest.mac over MacVerifyRequest.data was successful.
Corresponds to the JSON property success
2682 2683 2684 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2682 def success @success end |
#verified_data_crc32c ⇒ Boolean Also known as: verified_data_crc32c?
Integrity verification field. A flag indicating whether MacVerifyRequest.
data_crc32c was received by KeyManagementService and used for the integrity
verification of the data. A false value of this field indicates either that
MacVerifyRequest.data_crc32c was left unset or that it was not delivered to
KeyManagementService. If you've set MacVerifyRequest.data_crc32c but this
field is still false, discard the response and perform a limited number of
retries.
Corresponds to the JSON property verifiedDataCrc32c
2694 2695 2696 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2694 def verified_data_crc32c @verified_data_crc32c end |
#verified_mac_crc32c ⇒ Boolean Also known as: verified_mac_crc32c?
Integrity verification field. A flag indicating whether MacVerifyRequest.
mac_crc32c was received by KeyManagementService and used for the integrity
verification of the data. A false value of this field indicates either that
MacVerifyRequest.mac_crc32c was left unset or that it was not delivered to
KeyManagementService. If you've set MacVerifyRequest.mac_crc32c but this field
is still false, discard the response and perform a limited number of retries.
Corresponds to the JSON property verifiedMacCrc32c
2705 2706 2707 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2705 def verified_mac_crc32c @verified_mac_crc32c end |
#verified_success_integrity ⇒ Boolean Also known as: verified_success_integrity?
Integrity verification field. This value is used for the integrity
verification of [MacVerifyResponse.success]. If the value of this field
contradicts the value of [MacVerifyResponse.success], discard the response and
perform a limited number of retries.
Corresponds to the JSON property verifiedSuccessIntegrity
2714 2715 2716 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2714 def verified_success_integrity @verified_success_integrity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2722 def update!(**args) @name = args[:name] if args.key?(:name) @protection_level = args[:protection_level] if args.key?(:protection_level) @success = args[:success] if args.key?(:success) @verified_data_crc32c = args[:verified_data_crc32c] if args.key?(:verified_data_crc32c) @verified_mac_crc32c = args[:verified_mac_crc32c] if args.key?(:verified_mac_crc32c) @verified_success_integrity = args[:verified_success_integrity] if args.key?(:verified_success_integrity) end |