Class: Google::Apis::CloudkmsV1::PublicKey

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

The public keys for a given CryptoKeyVersion. Obtained via GetPublicKey.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicKey

Returns a new instance of PublicKey.



2924
2925
2926
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2924

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#algorithmString

The Algorithm associated with this key. Corresponds to the JSON property algorithm

Returns:

  • (String)


2878
2879
2880
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2878

def algorithm
  @algorithm
end

#nameString

The name of the CryptoKeyVersion public key. Provided here for verification. NOTE: This field is in Beta. Corresponds to the JSON property name

Returns:

  • (String)


2884
2885
2886
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2884

def name
  @name
end

#pemString

The public key, encoded in PEM format. For more information, see the RFC 7468 sections for General Considerations and Textual Encoding of Subject Public Key Info. Corresponds to the JSON property pem

Returns:

  • (String)


2892
2893
2894
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2892

def pem
  @pem
end

#pem_crc32cFixnum

Integrity verification field. A CRC32C checksum of the returned PublicKey.pem. An integrity check of PublicKey.pem can be performed by computing the CRC32C checksum of PublicKey.pem and comparing your results to this field. Discard the response in case of non-matching checksum values, and perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non- negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type. NOTE: This field is in Beta. Corresponds to the JSON property pemCrc32c

Returns:

  • (Fixnum)


2906
2907
2908
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2906

def pem_crc32c
  @pem_crc32c
end

#protection_levelString

The ProtectionLevel of the CryptoKeyVersion public key. Corresponds to the JSON property protectionLevel

Returns:

  • (String)


2911
2912
2913
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2911

def protection_level
  @protection_level
end

#public_keyGoogle::Apis::CloudkmsV1::ChecksummedData

Data with integrity verification field. Corresponds to the JSON property publicKey



2916
2917
2918
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2916

def public_key
  @public_key
end

#public_key_formatString

The PublicKey format specified by the customer through the public_key_format field. Corresponds to the JSON property publicKeyFormat

Returns:

  • (String)


2922
2923
2924
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2922

def public_key_format
  @public_key_format
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2929
2930
2931
2932
2933
2934
2935
2936
2937
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2929

def update!(**args)
  @algorithm = args[:algorithm] if args.key?(:algorithm)
  @name = args[:name] if args.key?(:name)
  @pem = args[:pem] if args.key?(:pem)
  @pem_crc32c = args[:pem_crc32c] if args.key?(:pem_crc32c)
  @protection_level = args[:protection_level] if args.key?(:protection_level)
  @public_key = args[:public_key] if args.key?(:public_key)
  @public_key_format = args[:public_key_format] if args.key?(:public_key_format)
end