Class: Google::Apis::CloudkmsV1::PublicKey
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::PublicKey
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
The public keys for a given CryptoKeyVersion. Obtained via GetPublicKey.
Instance Attribute Summary collapse
-
#algorithm ⇒ String
The Algorithm associated with this key.
-
#name ⇒ String
The name of the CryptoKeyVersion public key.
-
#pem ⇒ String
The public key, encoded in PEM format.
-
#pem_crc32c ⇒ Fixnum
Integrity verification field.
-
#protection_level ⇒ String
The ProtectionLevel of the CryptoKeyVersion public key.
-
#public_key ⇒ Google::Apis::CloudkmsV1::ChecksummedData
Data with integrity verification field.
-
#public_key_format ⇒ String
The PublicKey format specified by the customer through the public_key_format field.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicKey
constructor
A new instance of PublicKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicKey
Returns a new instance of PublicKey.
2875 2876 2877 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2875 def initialize(**args) update!(**args) end |
Instance Attribute Details
#algorithm ⇒ String
The Algorithm associated with this key.
Corresponds to the JSON property algorithm
2829 2830 2831 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2829 def algorithm @algorithm end |
#name ⇒ String
The name of the CryptoKeyVersion public key. Provided here for verification.
NOTE: This field is in Beta.
Corresponds to the JSON property name
2835 2836 2837 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2835 def name @name end |
#pem ⇒ String
The public key, encoded in PEM format. For more information, see the RFC 7468 sections for General Considerations and Textual Encoding of
Subject Public Key Info.
Corresponds to the JSON property pem
2843 2844 2845 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2843 def pem @pem end |
#pem_crc32c ⇒ Fixnum
Integrity verification field. A CRC32C checksum of the returned PublicKey.pem.
An integrity check of PublicKey.pem can be performed by computing the CRC32C
checksum of PublicKey.pem and comparing your results to this field. Discard
the response in case of non-matching checksum values, and perform a limited
number of retries. A persistent mismatch may indicate an issue in your
computation of the CRC32C checksum. Note: This field is defined as int64 for
reasons of compatibility across different languages. However, it is a non-
negative integer, which will never exceed 2^32-1, and can be safely
downconverted to uint32 in languages that support this type. NOTE: This field
is in Beta.
Corresponds to the JSON property pemCrc32c
2857 2858 2859 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2857 def pem_crc32c @pem_crc32c end |
#protection_level ⇒ String
The ProtectionLevel of the CryptoKeyVersion public key.
Corresponds to the JSON property protectionLevel
2862 2863 2864 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2862 def protection_level @protection_level end |
#public_key ⇒ Google::Apis::CloudkmsV1::ChecksummedData
Data with integrity verification field.
Corresponds to the JSON property publicKey
2867 2868 2869 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2867 def public_key @public_key end |
#public_key_format ⇒ String
The PublicKey format specified by the customer through the public_key_format
field.
Corresponds to the JSON property publicKeyFormat
2873 2874 2875 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2873 def public_key_format @public_key_format end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2880 2881 2882 2883 2884 2885 2886 2887 2888 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2880 def update!(**args) @algorithm = args[:algorithm] if args.key?(:algorithm) @name = args[:name] if args.key?(:name) @pem = args[:pem] if args.key?(:pem) @pem_crc32c = args[:pem_crc32c] if args.key?(:pem_crc32c) @protection_level = args[:protection_level] if args.key?(:protection_level) @public_key = args[:public_key] if args.key?(:public_key) @public_key_format = args[:public_key_format] if args.key?(:public_key_format) end |