Class: Google::Apis::CloudkmsV1::QuorumAuth

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

Configuration for M of N quorum auth.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuorumAuth

Returns a new instance of QuorumAuth.



2914
2915
2916
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2914

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#required_approver_countFixnum

Output only. The required numbers of approvers. The M value used for M of N quorum auth. Must be greater than or equal to 2 and less than or equal to total_approver_count - 1. Corresponds to the JSON property requiredApproverCount

Returns:

  • (Fixnum)


2900
2901
2902
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2900

def required_approver_count
  @required_approver_count
end

#total_approver_countFixnum

Required. The total number of approvers. This is the N value used for M of N quorum auth. Must be greater than or equal to 3 and less than or equal to 16. Corresponds to the JSON property totalApproverCount

Returns:

  • (Fixnum)


2906
2907
2908
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2906

def total_approver_count
  @total_approver_count
end

#two_factor_public_key_pemsArray<String>

Output only. The public keys associated with the 2FA keys for M of N quorum auth. Corresponds to the JSON property twoFactorPublicKeyPems

Returns:

  • (Array<String>)


2912
2913
2914
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2912

def two_factor_public_key_pems
  @two_factor_public_key_pems
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2919
2920
2921
2922
2923
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2919

def update!(**args)
  @required_approver_count = args[:required_approver_count] if args.key?(:required_approver_count)
  @total_approver_count = args[:total_approver_count] if args.key?(:total_approver_count)
  @two_factor_public_key_pems = args[:two_factor_public_key_pems] if args.key?(:two_factor_public_key_pems)
end