Class: Google::Apis::CloudkmsV1::QuorumParameters
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::QuorumParameters
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
Parameters of quorum approval for the SingleTenantHsmInstanceProposal.
Instance Attribute Summary collapse
-
#approved_two_factor_public_key_pems ⇒ Array<String>
Output only.
-
#challenges ⇒ Array<Google::Apis::CloudkmsV1::Challenge>
Output only.
-
#required_approver_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QuorumParameters
constructor
A new instance of QuorumParameters.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QuorumParameters
Returns a new instance of QuorumParameters.
3015 3016 3017 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3015 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approved_two_factor_public_key_pems ⇒ Array<String>
Output only. The public keys associated with the 2FA keys that have already
approved the SingleTenantHsmInstanceProposal by signing the challenge.
Corresponds to the JSON property approvedTwoFactorPublicKeyPems
3001 3002 3003 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3001 def approved_two_factor_public_key_pems @approved_two_factor_public_key_pems end |
#challenges ⇒ Array<Google::Apis::CloudkmsV1::Challenge>
Output only. The challenges to be signed by 2FA keys for quorum auth. M of N
of these challenges are required to be signed to approve the operation.
Corresponds to the JSON property challenges
3007 3008 3009 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3007 def challenges @challenges end |
#required_approver_count ⇒ Fixnum
Output only. The required numbers of approvers. This is the M value used for M
of N quorum auth. It is less than the number of public keys.
Corresponds to the JSON property requiredApproverCount
3013 3014 3015 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3013 def required_approver_count @required_approver_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3020 3021 3022 3023 3024 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3020 def update!(**args) @approved_two_factor_public_key_pems = args[:approved_two_factor_public_key_pems] if args.key?(:approved_two_factor_public_key_pems) @challenges = args[:challenges] if args.key?(:challenges) @required_approver_count = args[:required_approver_count] if args.key?(:required_approver_count) end |