Class: Google::Apis::CloudkmsV1::QuorumParameters

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

Parameters of quorum approval for the SingleTenantHsmInstanceProposal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuorumParameters

Returns a new instance of QuorumParameters.



2997
2998
2999
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2997

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approved_two_factor_public_key_pemsArray<String>

Output only. The public keys associated with the 2FA keys that have already approved the SingleTenantHsmInstanceProposal by signing the challenge. Corresponds to the JSON property approvedTwoFactorPublicKeyPems

Returns:

  • (Array<String>)


2983
2984
2985
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2983

def approved_two_factor_public_key_pems
  @approved_two_factor_public_key_pems
end

#challengesArray<Google::Apis::CloudkmsV1::Challenge>

Output only. The challenges to be signed by 2FA keys for quorum auth. M of N of these challenges are required to be signed to approve the operation. Corresponds to the JSON property challenges



2989
2990
2991
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2989

def challenges
  @challenges
end

#required_approver_countFixnum

Output only. The required numbers of approvers. This is the M value used for M of N quorum auth. It is less than the number of public keys. Corresponds to the JSON property requiredApproverCount

Returns:

  • (Fixnum)


2995
2996
2997
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2995

def required_approver_count
  @required_approver_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3002
3003
3004
3005
3006
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3002

def update!(**args)
  @approved_two_factor_public_key_pems = args[:approved_two_factor_public_key_pems] if args.key?(:approved_two_factor_public_key_pems)
  @challenges = args[:challenges] if args.key?(:challenges)
  @required_approver_count = args[:required_approver_count] if args.key?(:required_approver_count)
end