Class: Google::Apis::CloudkmsV1::RawDecryptRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

Request message for KeyManagementService.RawDecrypt.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RawDecryptRequest

Returns a new instance of RawDecryptRequest.



3058
3059
3060
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3058

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_authenticated_dataString

Optional. Optional data that must match the data originally supplied in RawEncryptRequest.additional_authenticated_data. Corresponds to the JSON property additionalAuthenticatedData NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


2990
2991
2992
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 2990

def additional_authenticated_data
  @additional_authenticated_data
end

#additional_authenticated_data_crc32cFixnum

Optional. An optional CRC32C checksum of the RawDecryptRequest. additional_authenticated_data. If specified, KeyManagementService will verify the integrity of the received additional_authenticated_data using this checksum. KeyManagementService will report an error if the checksum verification fails. If you receive a checksum error, your client should verify that CRC32C(additional_authenticated_data) is equal to additional_authenticated_data_crc32c, and if so, perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type. Corresponds to the JSON property additionalAuthenticatedDataCrc32c

Returns:

  • (Fixnum)


3006
3007
3008
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3006

def additional_authenticated_data_crc32c
  @additional_authenticated_data_crc32c
end

#ciphertextString

Required. The encrypted data originally returned in RawEncryptResponse. ciphertext. Corresponds to the JSON property ciphertext NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3013
3014
3015
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3013

def ciphertext
  @ciphertext
end

#ciphertext_crc32cFixnum

Optional. An optional CRC32C checksum of the RawDecryptRequest.ciphertext. If specified, KeyManagementService will verify the integrity of the received ciphertext using this checksum. KeyManagementService will report an error if the checksum verification fails. If you receive a checksum error, your client should verify that CRC32C(ciphertext) is equal to ciphertext_crc32c, and if so, perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type. Corresponds to the JSON property ciphertextCrc32c

Returns:

  • (Fixnum)


3027
3028
3029
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3027

def ciphertext_crc32c
  @ciphertext_crc32c
end

#initialization_vectorString

Required. The initialization vector (IV) used during encryption, which must match the data originally provided in RawEncryptResponse.initialization_vector. Corresponds to the JSON property initializationVector NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3034
3035
3036
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3034

def initialization_vector
  @initialization_vector
end

#initialization_vector_crc32cFixnum

Optional. An optional CRC32C checksum of the RawDecryptRequest. initialization_vector. If specified, KeyManagementService will verify the integrity of the received initialization_vector using this checksum. KeyManagementService will report an error if the checksum verification fails. If you receive a checksum error, your client should verify that CRC32C( initialization_vector) is equal to initialization_vector_crc32c, and if so, perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type. Corresponds to the JSON property initializationVectorCrc32c

Returns:

  • (Fixnum)


3049
3050
3051
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3049

def initialization_vector_crc32c
  @initialization_vector_crc32c
end

#tag_lengthFixnum

The length of the authentication tag that is appended to the end of the ciphertext. If unspecified (0), the default value for the key's algorithm will be used (for AES-GCM, the default value is 16). Corresponds to the JSON property tagLength

Returns:

  • (Fixnum)


3056
3057
3058
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3056

def tag_length
  @tag_length
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3063
3064
3065
3066
3067
3068
3069
3070
3071
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3063

def update!(**args)
  @additional_authenticated_data = args[:additional_authenticated_data] if args.key?(:additional_authenticated_data)
  @additional_authenticated_data_crc32c = args[:additional_authenticated_data_crc32c] if args.key?(:additional_authenticated_data_crc32c)
  @ciphertext = args[:ciphertext] if args.key?(:ciphertext)
  @ciphertext_crc32c = args[:ciphertext_crc32c] if args.key?(:ciphertext_crc32c)
  @initialization_vector = args[:initialization_vector] if args.key?(:initialization_vector)
  @initialization_vector_crc32c = args[:initialization_vector_crc32c] if args.key?(:initialization_vector_crc32c)
  @tag_length = args[:tag_length] if args.key?(:tag_length)
end