Class: Google::Apis::CloudkmsV1::RawEncryptResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::RawEncryptResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
Response message for KeyManagementService.RawEncrypt.
Instance Attribute Summary collapse
-
#ciphertext ⇒ String
The encrypted data.
-
#ciphertext_crc32c ⇒ Fixnum
Integrity verification field.
-
#initialization_vector ⇒ String
The initialization vector (IV) generated by the service during encryption.
-
#initialization_vector_crc32c ⇒ Fixnum
Integrity verification field.
-
#name ⇒ String
The resource name of the CryptoKeyVersion used in encryption.
-
#protection_level ⇒ String
The ProtectionLevel of the CryptoKeyVersion used in encryption.
-
#tag_length ⇒ Fixnum
The length of the authentication tag that is appended to the end of the ciphertext.
-
#verified_additional_authenticated_data_crc32c ⇒ Boolean
(also: #verified_additional_authenticated_data_crc32c?)
Integrity verification field.
-
#verified_initialization_vector_crc32c ⇒ Boolean
(also: #verified_initialization_vector_crc32c?)
Integrity verification field.
-
#verified_plaintext_crc32c ⇒ Boolean
(also: #verified_plaintext_crc32c?)
Integrity verification field.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RawEncryptResponse
constructor
A new instance of RawEncryptResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RawEncryptResponse
Returns a new instance of RawEncryptResponse.
3399 3400 3401 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3399 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ciphertext ⇒ String
The encrypted data. In the case of AES-GCM, the authentication tag is the
tag_length bytes at the end of this field.
Corresponds to the JSON property ciphertext
NOTE: Values are automatically base64 encoded/decoded in the client library.
3308 3309 3310 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3308 def ciphertext @ciphertext end |
#ciphertext_crc32c ⇒ Fixnum
Integrity verification field. A CRC32C checksum of the returned
RawEncryptResponse.ciphertext. An integrity check of ciphertext can be
performed by computing the CRC32C checksum of ciphertext and comparing your
results to this field. Discard the response in case of non-matching checksum
values, and perform a limited number of retries. A persistent mismatch may
indicate an issue in your computation of the CRC32C checksum. Note: This field
is defined as int64 for reasons of compatibility across different languages.
However, it is a non-negative integer, which will never exceed 2^32-1, and can
be safely downconverted to uint32 in languages that support this type.
Corresponds to the JSON property ciphertextCrc32c
3321 3322 3323 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3321 def ciphertext_crc32c @ciphertext_crc32c end |
#initialization_vector ⇒ String
The initialization vector (IV) generated by the service during encryption.
This value must be stored and provided in RawDecryptRequest.
initialization_vector at decryption time.
Corresponds to the JSON property initializationVector
NOTE: Values are automatically base64 encoded/decoded in the client library.
3329 3330 3331 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3329 def initialization_vector @initialization_vector end |
#initialization_vector_crc32c ⇒ Fixnum
Integrity verification field. A CRC32C checksum of the returned
RawEncryptResponse.initialization_vector. An integrity check of
initialization_vector can be performed by computing the CRC32C checksum of
initialization_vector and comparing your results to this field. Discard the
response in case of non-matching checksum values, and perform a limited number
of retries. A persistent mismatch may indicate an issue in your computation of
the CRC32C checksum. Note: This field is defined as int64 for reasons of
compatibility across different languages. However, it is a non-negative
integer, which will never exceed 2^32-1, and can be safely downconverted to
uint32 in languages that support this type.
Corresponds to the JSON property initializationVectorCrc32c
3343 3344 3345 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3343 def initialization_vector_crc32c @initialization_vector_crc32c end |
#name ⇒ String
The resource name of the CryptoKeyVersion used in encryption. Check this field
to verify that the intended resource was used for encryption.
Corresponds to the JSON property name
3349 3350 3351 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3349 def name @name end |
#protection_level ⇒ String
The ProtectionLevel of the CryptoKeyVersion used in encryption.
Corresponds to the JSON property protectionLevel
3354 3355 3356 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3354 def protection_level @protection_level end |
#tag_length ⇒ Fixnum
The length of the authentication tag that is appended to the end of the
ciphertext.
Corresponds to the JSON property tagLength
3360 3361 3362 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3360 def tag_length @tag_length end |
#verified_additional_authenticated_data_crc32c ⇒ Boolean Also known as: verified_additional_authenticated_data_crc32c?
Integrity verification field. A flag indicating whether RawEncryptRequest.
additional_authenticated_data_crc32c was received by KeyManagementService and
used for the integrity verification of additional_authenticated_data. A false
value of this field indicates either that // RawEncryptRequest.
additional_authenticated_data_crc32c was left unset or that it was not
delivered to KeyManagementService. If you've set RawEncryptRequest.
additional_authenticated_data_crc32c but this field is still false, discard
the response and perform a limited number of retries.
Corresponds to the JSON property verifiedAdditionalAuthenticatedDataCrc32c
3372 3373 3374 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3372 def verified_additional_authenticated_data_crc32c @verified_additional_authenticated_data_crc32c end |
#verified_initialization_vector_crc32c ⇒ Boolean Also known as: verified_initialization_vector_crc32c?
Integrity verification field. A flag indicating whether RawEncryptRequest.
initialization_vector_crc32c was received by KeyManagementService and used for
the integrity verification of initialization_vector. A false value of this
field indicates either that RawEncryptRequest.initialization_vector_crc32c was
left unset or that it was not delivered to KeyManagementService. If you've set
RawEncryptRequest.initialization_vector_crc32c but this field is still false,
discard the response and perform a limited number of retries.
Corresponds to the JSON property verifiedInitializationVectorCrc32c
3384 3385 3386 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3384 def verified_initialization_vector_crc32c @verified_initialization_vector_crc32c end |
#verified_plaintext_crc32c ⇒ Boolean Also known as: verified_plaintext_crc32c?
Integrity verification field. A flag indicating whether RawEncryptRequest.
plaintext_crc32c was received by KeyManagementService and used for the
integrity verification of the plaintext. A false value of this field indicates
either that RawEncryptRequest.plaintext_crc32c was left unset or that it was
not delivered to KeyManagementService. If you've set RawEncryptRequest.
plaintext_crc32c but this field is still false, discard the response and
perform a limited number of retries.
Corresponds to the JSON property verifiedPlaintextCrc32c
3396 3397 3398 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3396 def verified_plaintext_crc32c @verified_plaintext_crc32c end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3404 def update!(**args) @ciphertext = args[:ciphertext] if args.key?(:ciphertext) @ciphertext_crc32c = args[:ciphertext_crc32c] if args.key?(:ciphertext_crc32c) @initialization_vector = args[:initialization_vector] if args.key?(:initialization_vector) @initialization_vector_crc32c = args[:initialization_vector_crc32c] if args.key?(:initialization_vector_crc32c) @name = args[:name] if args.key?(:name) @protection_level = args[:protection_level] if args.key?(:protection_level) @tag_length = args[:tag_length] if args.key?(:tag_length) @verified_additional_authenticated_data_crc32c = args[:verified_additional_authenticated_data_crc32c] if args.key?(:verified_additional_authenticated_data_crc32c) @verified_initialization_vector_crc32c = args[:verified_initialization_vector_crc32c] if args.key?(:verified_initialization_vector_crc32c) @verified_plaintext_crc32c = args[:verified_plaintext_crc32c] if args.key?(:verified_plaintext_crc32c) end |