Class: Google::Apis::CloudkmsV1::RawEncryptResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

Response message for KeyManagementService.RawEncrypt.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RawEncryptResponse

Returns a new instance of RawEncryptResponse.



3350
3351
3352
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3350

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ciphertextString

The encrypted data. In the case of AES-GCM, the authentication tag is the tag_length bytes at the end of this field. Corresponds to the JSON property ciphertext NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3259
3260
3261
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3259

def ciphertext
  @ciphertext
end

#ciphertext_crc32cFixnum

Integrity verification field. A CRC32C checksum of the returned RawEncryptResponse.ciphertext. An integrity check of ciphertext can be performed by computing the CRC32C checksum of ciphertext and comparing your results to this field. Discard the response in case of non-matching checksum values, and perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type. Corresponds to the JSON property ciphertextCrc32c

Returns:

  • (Fixnum)


3272
3273
3274
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3272

def ciphertext_crc32c
  @ciphertext_crc32c
end

#initialization_vectorString

The initialization vector (IV) generated by the service during encryption. This value must be stored and provided in RawDecryptRequest. initialization_vector at decryption time. Corresponds to the JSON property initializationVector NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3280
3281
3282
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3280

def initialization_vector
  @initialization_vector
end

#initialization_vector_crc32cFixnum

Integrity verification field. A CRC32C checksum of the returned RawEncryptResponse.initialization_vector. An integrity check of initialization_vector can be performed by computing the CRC32C checksum of initialization_vector and comparing your results to this field. Discard the response in case of non-matching checksum values, and perform a limited number of retries. A persistent mismatch may indicate an issue in your computation of the CRC32C checksum. Note: This field is defined as int64 for reasons of compatibility across different languages. However, it is a non-negative integer, which will never exceed 2^32-1, and can be safely downconverted to uint32 in languages that support this type. Corresponds to the JSON property initializationVectorCrc32c

Returns:

  • (Fixnum)


3294
3295
3296
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3294

def initialization_vector_crc32c
  @initialization_vector_crc32c
end

#nameString

The resource name of the CryptoKeyVersion used in encryption. Check this field to verify that the intended resource was used for encryption. Corresponds to the JSON property name

Returns:

  • (String)


3300
3301
3302
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3300

def name
  @name
end

#protection_levelString

The ProtectionLevel of the CryptoKeyVersion used in encryption. Corresponds to the JSON property protectionLevel

Returns:

  • (String)


3305
3306
3307
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3305

def protection_level
  @protection_level
end

#tag_lengthFixnum

The length of the authentication tag that is appended to the end of the ciphertext. Corresponds to the JSON property tagLength

Returns:

  • (Fixnum)


3311
3312
3313
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3311

def tag_length
  @tag_length
end

#verified_additional_authenticated_data_crc32cBoolean Also known as: verified_additional_authenticated_data_crc32c?

Integrity verification field. A flag indicating whether RawEncryptRequest. additional_authenticated_data_crc32c was received by KeyManagementService and used for the integrity verification of additional_authenticated_data. A false value of this field indicates either that // RawEncryptRequest. additional_authenticated_data_crc32c was left unset or that it was not delivered to KeyManagementService. If you've set RawEncryptRequest. additional_authenticated_data_crc32c but this field is still false, discard the response and perform a limited number of retries. Corresponds to the JSON property verifiedAdditionalAuthenticatedDataCrc32c

Returns:

  • (Boolean)


3323
3324
3325
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3323

def verified_additional_authenticated_data_crc32c
  @verified_additional_authenticated_data_crc32c
end

#verified_initialization_vector_crc32cBoolean Also known as: verified_initialization_vector_crc32c?

Integrity verification field. A flag indicating whether RawEncryptRequest. initialization_vector_crc32c was received by KeyManagementService and used for the integrity verification of initialization_vector. A false value of this field indicates either that RawEncryptRequest.initialization_vector_crc32c was left unset or that it was not delivered to KeyManagementService. If you've set RawEncryptRequest.initialization_vector_crc32c but this field is still false, discard the response and perform a limited number of retries. Corresponds to the JSON property verifiedInitializationVectorCrc32c

Returns:

  • (Boolean)


3335
3336
3337
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3335

def verified_initialization_vector_crc32c
  @verified_initialization_vector_crc32c
end

#verified_plaintext_crc32cBoolean Also known as: verified_plaintext_crc32c?

Integrity verification field. A flag indicating whether RawEncryptRequest. plaintext_crc32c was received by KeyManagementService and used for the integrity verification of the plaintext. A false value of this field indicates either that RawEncryptRequest.plaintext_crc32c was left unset or that it was not delivered to KeyManagementService. If you've set RawEncryptRequest. plaintext_crc32c but this field is still false, discard the response and perform a limited number of retries. Corresponds to the JSON property verifiedPlaintextCrc32c

Returns:

  • (Boolean)


3347
3348
3349
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3347

def verified_plaintext_crc32c
  @verified_plaintext_crc32c
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
3365
3366
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3355

def update!(**args)
  @ciphertext = args[:ciphertext] if args.key?(:ciphertext)
  @ciphertext_crc32c = args[:ciphertext_crc32c] if args.key?(:ciphertext_crc32c)
  @initialization_vector = args[:initialization_vector] if args.key?(:initialization_vector)
  @initialization_vector_crc32c = args[:initialization_vector_crc32c] if args.key?(:initialization_vector_crc32c)
  @name = args[:name] if args.key?(:name)
  @protection_level = args[:protection_level] if args.key?(:protection_level)
  @tag_length = args[:tag_length] if args.key?(:tag_length)
  @verified_additional_authenticated_data_crc32c = args[:verified_additional_authenticated_data_crc32c] if args.key?(:verified_additional_authenticated_data_crc32c)
  @verified_initialization_vector_crc32c = args[:verified_initialization_vector_crc32c] if args.key?(:verified_initialization_vector_crc32c)
  @verified_plaintext_crc32c = args[:verified_plaintext_crc32c] if args.key?(:verified_plaintext_crc32c)
end