Class: Google::Apis::CloudkmsV1::RequiredActionQuorumParameters

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

Parameters for an approval that has both required challenges and a quorum.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RequiredActionQuorumParameters

Returns a new instance of RequiredActionQuorumParameters.



3466
3467
3468
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3466

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approved_two_factor_public_key_pemsArray<String>

Output only. The public keys associated with the 2FA keys that have already approved the SingleTenantHsmInstanceProposal by signing the challenge. Corresponds to the JSON property approvedTwoFactorPublicKeyPems

Returns:

  • (Array<String>)


3446
3447
3448
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3446

def approved_two_factor_public_key_pems
  @approved_two_factor_public_key_pems
end

#quorum_challengesArray<Google::Apis::CloudkmsV1::Challenge>

Output only. The challenges to be signed by 2FA keys for quorum auth. M of N of these challenges are required to be signed to approve the operation. Corresponds to the JSON property quorumChallenges



3452
3453
3454
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3452

def quorum_challenges
  @quorum_challenges
end

#required_approver_countFixnum

Output only. The required number of quorum approvers. This is the M value used for M of N quorum auth. It is less than the number of public keys. Corresponds to the JSON property requiredApproverCount

Returns:

  • (Fixnum)


3458
3459
3460
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3458

def required_approver_count
  @required_approver_count
end

#required_challengesArray<Google::Apis::CloudkmsV1::Challenge>

Output only. A list of specific challenges that must be signed. For some operations, this will contain a single challenge. Corresponds to the JSON property requiredChallenges



3464
3465
3466
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3464

def required_challenges
  @required_challenges
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3471
3472
3473
3474
3475
3476
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3471

def update!(**args)
  @approved_two_factor_public_key_pems = args[:approved_two_factor_public_key_pems] if args.key?(:approved_two_factor_public_key_pems)
  @quorum_challenges = args[:quorum_challenges] if args.key?(:quorum_challenges)
  @required_approver_count = args[:required_approver_count] if args.key?(:required_approver_count)
  @required_challenges = args[:required_challenges] if args.key?(:required_challenges)
end