Class: Google::Apis::CloudkmsV1::RetiredResource
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::RetiredResource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
A RetiredResource resource represents the record of a deleted CryptoKey. Its purpose is to provide visibility into retained user data and to prevent reuse of these names for new CryptoKeys.
Instance Attribute Summary collapse
-
#delete_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#original_resource ⇒ String
Output only.
-
#resource_type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RetiredResource
constructor
A new instance of RetiredResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RetiredResource
Returns a new instance of RetiredResource.
3752 3753 3754 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3752 def initialize(**args) update!(**args) end |
Instance Attribute Details
#delete_time ⇒ String
Output only. The time at which the original resource was deleted and this
RetiredResource record was created.
Corresponds to the JSON property deleteTime
3733 3734 3735 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3733 def delete_time @delete_time end |
#name ⇒ String
Output only. Identifier. The resource name for this RetiredResource in the
format projects/*/locations/*/retiredResources/*.
Corresponds to the JSON property name
3739 3740 3741 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3739 def name @name end |
#original_resource ⇒ String
Output only. The full resource name of the original CryptoKey that was deleted
in the format projects/*/locations/*/keyRings/*/cryptoKeys/*.
Corresponds to the JSON property originalResource
3745 3746 3747 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3745 def original_resource @original_resource end |
#resource_type ⇒ String
Output only. The resource type of the original deleted resource.
Corresponds to the JSON property resourceType
3750 3751 3752 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3750 def resource_type @resource_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3757 3758 3759 3760 3761 3762 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3757 def update!(**args) @delete_time = args[:delete_time] if args.key?(:delete_time) @name = args[:name] if args.key?(:name) @original_resource = args[:original_resource] if args.key?(:original_resource) @resource_type = args[:resource_type] if args.key?(:resource_type) end |