Class: Google::Apis::CloudkmsV1::RetiredResource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

A RetiredResource resource represents the record of a deleted CryptoKey. Its purpose is to provide visibility into retained user data and to prevent reuse of these names for new CryptoKeys.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RetiredResource

Returns a new instance of RetiredResource.



3617
3618
3619
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3617

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delete_timeString

Output only. The time at which the original resource was deleted and this RetiredResource record was created. Corresponds to the JSON property deleteTime

Returns:

  • (String)


3598
3599
3600
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3598

def delete_time
  @delete_time
end

#nameString

Output only. Identifier. The resource name for this RetiredResource in the format projects/*/locations/*/retiredResources/*. Corresponds to the JSON property name

Returns:

  • (String)


3604
3605
3606
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3604

def name
  @name
end

#original_resourceString

Output only. The full resource name of the original CryptoKey that was deleted in the format projects/*/locations/*/keyRings/*/cryptoKeys/*. Corresponds to the JSON property originalResource

Returns:

  • (String)


3610
3611
3612
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3610

def original_resource
  @original_resource
end

#resource_typeString

Output only. The resource type of the original deleted resource. Corresponds to the JSON property resourceType

Returns:

  • (String)


3615
3616
3617
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3615

def resource_type
  @resource_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3622
3623
3624
3625
3626
3627
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3622

def update!(**args)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @name = args[:name] if args.key?(:name)
  @original_resource = args[:original_resource] if args.key?(:original_resource)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
end