Class: Google::Apis::CloudkmsV1::ServiceResolver

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

A ServiceResolver represents an EKM replica that can be reached within an EkmConnection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceResolver

Returns a new instance of ServiceResolver.



3669
3670
3671
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3669

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endpoint_filterString

Optional. The filter applied to the endpoints of the resolved service. If no filter is specified, all endpoints will be considered. An endpoint will be chosen arbitrarily from the filtered list for each request. For endpoint filter syntax and examples, see https://cloud.google.com/service-directory/ docs/reference/rpc/google.cloud.servicedirectory.v1#resolveservicerequest. Corresponds to the JSON property endpointFilter

Returns:

  • (String)


3649
3650
3651
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3649

def endpoint_filter
  @endpoint_filter
end

#hostnameString

Required. The hostname of the EKM replica used at TLS and HTTP layers. Corresponds to the JSON property hostname

Returns:

  • (String)


3654
3655
3656
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3654

def hostname
  @hostname
end

#server_certificatesArray<Google::Apis::CloudkmsV1::Certificate>

Required. A list of leaf server certificates used to authenticate HTTPS connections to the EKM replica. Currently, a maximum of 10 Certificate is supported. Corresponds to the JSON property serverCertificates



3661
3662
3663
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3661

def server_certificates
  @server_certificates
end

#service_directory_serviceString

Required. The resource name of the Service Directory service pointing to an EKM replica, in the format projects/*/locations/*/namespaces/*/services/*. Corresponds to the JSON property serviceDirectoryService

Returns:

  • (String)


3667
3668
3669
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3667

def service_directory_service
  @service_directory_service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3674
3675
3676
3677
3678
3679
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3674

def update!(**args)
  @endpoint_filter = args[:endpoint_filter] if args.key?(:endpoint_filter)
  @hostname = args[:hostname] if args.key?(:hostname)
  @server_certificates = args[:server_certificates] if args.key?(:server_certificates)
  @service_directory_service = args[:service_directory_service] if args.key?(:service_directory_service)
end