Class: Google::Apis::CloudkmsV1::ServiceResolver
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::ServiceResolver
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
A ServiceResolver represents an EKM replica that can be reached within an EkmConnection.
Instance Attribute Summary collapse
-
#endpoint_filter ⇒ String
Optional.
-
#hostname ⇒ String
Required.
-
#server_certificates ⇒ Array<Google::Apis::CloudkmsV1::Certificate>
Required.
-
#service_directory_service ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceResolver
constructor
A new instance of ServiceResolver.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceResolver
Returns a new instance of ServiceResolver.
3553 3554 3555 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3553 def initialize(**args) update!(**args) end |
Instance Attribute Details
#endpoint_filter ⇒ String
Optional. The filter applied to the endpoints of the resolved service. If no
filter is specified, all endpoints will be considered. An endpoint will be
chosen arbitrarily from the filtered list for each request. For endpoint
filter syntax and examples, see https://cloud.google.com/service-directory/
docs/reference/rpc/google.cloud.servicedirectory.v1#resolveservicerequest.
Corresponds to the JSON property endpointFilter
3533 3534 3535 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3533 def endpoint_filter @endpoint_filter end |
#hostname ⇒ String
Required. The hostname of the EKM replica used at TLS and HTTP layers.
Corresponds to the JSON property hostname
3538 3539 3540 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3538 def hostname @hostname end |
#server_certificates ⇒ Array<Google::Apis::CloudkmsV1::Certificate>
Required. A list of leaf server certificates used to authenticate HTTPS
connections to the EKM replica. Currently, a maximum of 10 Certificate is
supported.
Corresponds to the JSON property serverCertificates
3545 3546 3547 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3545 def server_certificates @server_certificates end |
#service_directory_service ⇒ String
Required. The resource name of the Service Directory service pointing to an
EKM replica, in the format projects/*/locations/*/namespaces/*/services/*.
Corresponds to the JSON property serviceDirectoryService
3551 3552 3553 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3551 def service_directory_service @service_directory_service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3558 3559 3560 3561 3562 3563 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3558 def update!(**args) @endpoint_filter = args[:endpoint_filter] if args.key?(:endpoint_filter) @hostname = args[:hostname] if args.key?(:hostname) @server_certificates = args[:server_certificates] if args.key?(:server_certificates) @service_directory_service = args[:service_directory_service] if args.key?(:service_directory_service) end |