Class: Google::Apis::CloudkmsV1::ShowEffectiveKeyAccessJustificationsEnrollmentConfigResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::ShowEffectiveKeyAccessJustificationsEnrollmentConfigResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
Represents a response message for KeyAccessJustificationsConfig. ShowEffectiveKeyAccessJustificationsEnrollmentConfig
Instance Attribute Summary collapse
-
#external_config ⇒ Google::Apis::CloudkmsV1::KeyAccessJustificationsEnrollmentConfig
Represents the configuration of a protection level for a project's Key Access Justifications enrollment.
-
#hardware_config ⇒ Google::Apis::CloudkmsV1::KeyAccessJustificationsEnrollmentConfig
Represents the configuration of a protection level for a project's Key Access Justifications enrollment.
-
#software_config ⇒ Google::Apis::CloudkmsV1::KeyAccessJustificationsEnrollmentConfig
Represents the configuration of a protection level for a project's Key Access Justifications enrollment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ShowEffectiveKeyAccessJustificationsEnrollmentConfigResponse
constructor
A new instance of ShowEffectiveKeyAccessJustificationsEnrollmentConfigResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ShowEffectiveKeyAccessJustificationsEnrollmentConfigResponse
Returns a new instance of ShowEffectiveKeyAccessJustificationsEnrollmentConfigResponse.
3770 3771 3772 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3770 def initialize(**args) update!(**args) end |
Instance Attribute Details
#external_config ⇒ Google::Apis::CloudkmsV1::KeyAccessJustificationsEnrollmentConfig
Represents the configuration of a protection level for a project's Key Access
Justifications enrollment.
Corresponds to the JSON property externalConfig
3756 3757 3758 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3756 def external_config @external_config end |
#hardware_config ⇒ Google::Apis::CloudkmsV1::KeyAccessJustificationsEnrollmentConfig
Represents the configuration of a protection level for a project's Key Access
Justifications enrollment.
Corresponds to the JSON property hardwareConfig
3762 3763 3764 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3762 def hardware_config @hardware_config end |
#software_config ⇒ Google::Apis::CloudkmsV1::KeyAccessJustificationsEnrollmentConfig
Represents the configuration of a protection level for a project's Key Access
Justifications enrollment.
Corresponds to the JSON property softwareConfig
3768 3769 3770 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3768 def software_config @software_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3775 3776 3777 3778 3779 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3775 def update!(**args) @external_config = args[:external_config] if args.key?(:external_config) @hardware_config = args[:hardware_config] if args.key?(:hardware_config) @software_config = args[:software_config] if args.key?(:software_config) end |