Class: Google::Apis::CloudkmsV1::SingleTenantHsmInstance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

A SingleTenantHsmInstance represents a single-tenant HSM instance. It can be used for creating CryptoKeys with a ProtectionLevel of HSM_SINGLE_TENANT, as well as performing cryptographic operations using keys created within the SingleTenantHsmInstance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SingleTenantHsmInstance

Returns a new instance of SingleTenantHsmInstance.



3867
3868
3869
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3867

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which the SingleTenantHsmInstance was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3820
3821
3822
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3820

def create_time
  @create_time
end

#delete_timeString

Output only. The time at which the SingleTenantHsmInstance was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


3825
3826
3827
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3825

def delete_time
  @delete_time
end

#disable_timeString

Output only. The time at which the instance will be automatically disabled if not refreshed. This field is updated upon creation and after each successful refresh operation and enable. A RefreshSingleTenantHsmInstance operation must be made via a SingleTenantHsmInstanceProposal before this time otherwise the SingleTenantHsmInstance will become disabled. Corresponds to the JSON property disableTime

Returns:

  • (String)


3834
3835
3836
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3834

def disable_time
  @disable_time
end

#key_portability_enabledBoolean Also known as: key_portability_enabled?

Optional. Immutable. Indicates whether key portability is enabled for the SingleTenantHsmInstance. This can only be set at creation time. Key portability features are disabled by default and not yet available in GA. Corresponds to the JSON property keyPortabilityEnabled

Returns:

  • (Boolean)


3841
3842
3843
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3841

def key_portability_enabled
  @key_portability_enabled
end

#nameString

Identifier. The resource name for this SingleTenantHsmInstance in the format projects/*/locations/*/singleTenantHsmInstances/*. Corresponds to the JSON property name

Returns:

  • (String)


3848
3849
3850
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3848

def name
  @name
end

#quorum_authGoogle::Apis::CloudkmsV1::QuorumAuth

Configuration for M of N quorum auth. Corresponds to the JSON property quorumAuth



3853
3854
3855
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3853

def quorum_auth
  @quorum_auth
end

#stateString

Output only. The state of the SingleTenantHsmInstance. Corresponds to the JSON property state

Returns:

  • (String)


3858
3859
3860
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3858

def state
  @state
end

#unrefreshed_duration_until_disableString

Output only. The system-defined duration that an instance can remain unrefreshed until it is automatically disabled. This will have a value of 730 days. Corresponds to the JSON property unrefreshedDurationUntilDisable

Returns:

  • (String)


3865
3866
3867
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3865

def unrefreshed_duration_until_disable
  @unrefreshed_duration_until_disable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3872
3873
3874
3875
3876
3877
3878
3879
3880
3881
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3872

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @disable_time = args[:disable_time] if args.key?(:disable_time)
  @key_portability_enabled = args[:key_portability_enabled] if args.key?(:key_portability_enabled)
  @name = args[:name] if args.key?(:name)
  @quorum_auth = args[:quorum_auth] if args.key?(:quorum_auth)
  @state = args[:state] if args.key?(:state)
  @unrefreshed_duration_until_disable = args[:unrefreshed_duration_until_disable] if args.key?(:unrefreshed_duration_until_disable)
end