Class: Google::Apis::CloudkmsV1::SingleTenantHsmInstance
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::SingleTenantHsmInstance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
A SingleTenantHsmInstance represents a single-tenant HSM instance. It can be used for creating CryptoKeys with a ProtectionLevel of HSM_SINGLE_TENANT, as well as performing cryptographic operations using keys created within the SingleTenantHsmInstance.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#disable_time ⇒ String
Output only.
-
#key_portability_enabled ⇒ Boolean
(also: #key_portability_enabled?)
Optional.
-
#name ⇒ String
Identifier.
-
#quorum_auth ⇒ Google::Apis::CloudkmsV1::QuorumAuth
Configuration for M of N quorum auth.
-
#state ⇒ String
Output only.
-
#unrefreshed_duration_until_disable ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SingleTenantHsmInstance
constructor
A new instance of SingleTenantHsmInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SingleTenantHsmInstance
Returns a new instance of SingleTenantHsmInstance.
3866 3867 3868 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3866 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the SingleTenantHsmInstance was created.
Corresponds to the JSON property createTime
3819 3820 3821 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3819 def create_time @create_time end |
#delete_time ⇒ String
Output only. The time at which the SingleTenantHsmInstance was deleted.
Corresponds to the JSON property deleteTime
3824 3825 3826 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3824 def delete_time @delete_time end |
#disable_time ⇒ String
Output only. The time at which the instance will be automatically disabled if
not refreshed. This field is updated upon creation and after each successful
refresh operation and enable. A RefreshSingleTenantHsmInstance operation must
be made via a SingleTenantHsmInstanceProposal before this time otherwise the
SingleTenantHsmInstance will become disabled.
Corresponds to the JSON property disableTime
3833 3834 3835 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3833 def disable_time @disable_time end |
#key_portability_enabled ⇒ Boolean Also known as: key_portability_enabled?
Optional. Immutable. Indicates whether key portability is enabled for the
SingleTenantHsmInstance. This can only be set at creation time. Key
portability features are disabled by default and not yet available in GA.
Corresponds to the JSON property keyPortabilityEnabled
3840 3841 3842 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3840 def key_portability_enabled @key_portability_enabled end |
#name ⇒ String
Identifier. The resource name for this SingleTenantHsmInstance in the format
projects/*/locations/*/singleTenantHsmInstances/*.
Corresponds to the JSON property name
3847 3848 3849 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3847 def name @name end |
#quorum_auth ⇒ Google::Apis::CloudkmsV1::QuorumAuth
Configuration for M of N quorum auth.
Corresponds to the JSON property quorumAuth
3852 3853 3854 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3852 def quorum_auth @quorum_auth end |
#state ⇒ String
Output only. The state of the SingleTenantHsmInstance.
Corresponds to the JSON property state
3857 3858 3859 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3857 def state @state end |
#unrefreshed_duration_until_disable ⇒ String
Output only. The system-defined duration that an instance can remain
unrefreshed until it is automatically disabled. This will have a value of 730
days.
Corresponds to the JSON property unrefreshedDurationUntilDisable
3864 3865 3866 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3864 def unrefreshed_duration_until_disable @unrefreshed_duration_until_disable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3871 3872 3873 3874 3875 3876 3877 3878 3879 3880 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3871 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @disable_time = args[:disable_time] if args.key?(:disable_time) @key_portability_enabled = args[:key_portability_enabled] if args.key?(:key_portability_enabled) @name = args[:name] if args.key?(:name) @quorum_auth = args[:quorum_auth] if args.key?(:quorum_auth) @state = args[:state] if args.key?(:state) @unrefreshed_duration_until_disable = args[:unrefreshed_duration_until_disable] if args.key?(:unrefreshed_duration_until_disable) end |