Class: Google::Apis::CloudkmsV1::SingleTenantHsmInstance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

A SingleTenantHsmInstance represents a single-tenant HSM instance. It can be used for creating CryptoKeys with a ProtectionLevel of HSM_SINGLE_TENANT, as well as performing cryptographic operations using keys created within the SingleTenantHsmInstance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SingleTenantHsmInstance

Returns a new instance of SingleTenantHsmInstance.



3859
3860
3861
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3859

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time at which the SingleTenantHsmInstance was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3812
3813
3814
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3812

def create_time
  @create_time
end

#delete_timeString

Output only. The time at which the SingleTenantHsmInstance was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


3817
3818
3819
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3817

def delete_time
  @delete_time
end

#disable_timeString

Output only. The time at which the instance will be automatically disabled if not refreshed. This field is updated upon creation and after each successful refresh operation and enable. A RefreshSingleTenantHsmInstance operation must be made via a SingleTenantHsmInstanceProposal before this time otherwise the SingleTenantHsmInstance will become disabled. Corresponds to the JSON property disableTime

Returns:

  • (String)


3826
3827
3828
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3826

def disable_time
  @disable_time
end

#key_portability_enabledBoolean Also known as: key_portability_enabled?

Optional. Immutable. Indicates whether key portability is enabled for the SingleTenantHsmInstance. This can only be set at creation time. Key portability features are disabled by default and not yet available in GA. Corresponds to the JSON property keyPortabilityEnabled

Returns:

  • (Boolean)


3833
3834
3835
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3833

def key_portability_enabled
  @key_portability_enabled
end

#nameString

Identifier. The resource name for this SingleTenantHsmInstance in the format projects/*/locations/*/singleTenantHsmInstances/*. Corresponds to the JSON property name

Returns:

  • (String)


3840
3841
3842
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3840

def name
  @name
end

#quorum_authGoogle::Apis::CloudkmsV1::QuorumAuth

Configuration for M of N quorum auth. Corresponds to the JSON property quorumAuth



3845
3846
3847
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3845

def quorum_auth
  @quorum_auth
end

#stateString

Output only. The state of the SingleTenantHsmInstance. Corresponds to the JSON property state

Returns:

  • (String)


3850
3851
3852
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3850

def state
  @state
end

#unrefreshed_duration_until_disableString

Output only. The system-defined duration that an instance can remain unrefreshed until it is automatically disabled. This will have a value of 120 days. Corresponds to the JSON property unrefreshedDurationUntilDisable

Returns:

  • (String)


3857
3858
3859
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3857

def unrefreshed_duration_until_disable
  @unrefreshed_duration_until_disable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3864
3865
3866
3867
3868
3869
3870
3871
3872
3873
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3864

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @disable_time = args[:disable_time] if args.key?(:disable_time)
  @key_portability_enabled = args[:key_portability_enabled] if args.key?(:key_portability_enabled)
  @name = args[:name] if args.key?(:name)
  @quorum_auth = args[:quorum_auth] if args.key?(:quorum_auth)
  @state = args[:state] if args.key?(:state)
  @unrefreshed_duration_until_disable = args[:unrefreshed_duration_until_disable] if args.key?(:unrefreshed_duration_until_disable)
end