Class: Google::Apis::CloudkmsV1::SingleTenantHsmInstance
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::SingleTenantHsmInstance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
A SingleTenantHsmInstance represents a single-tenant HSM instance. It can be used for creating CryptoKeys with a ProtectionLevel of HSM_SINGLE_TENANT, as well as performing cryptographic operations using keys created within the SingleTenantHsmInstance.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#disable_time ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#quorum_auth ⇒ Google::Apis::CloudkmsV1::QuorumAuth
Configuration for M of N quorum auth.
-
#state ⇒ String
Output only.
-
#unrefreshed_duration_until_disable ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SingleTenantHsmInstance
constructor
A new instance of SingleTenantHsmInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SingleTenantHsmInstance
Returns a new instance of SingleTenantHsmInstance.
3742 3743 3744 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3742 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time at which the SingleTenantHsmInstance was created.
Corresponds to the JSON property createTime
3703 3704 3705 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3703 def create_time @create_time end |
#delete_time ⇒ String
Output only. The time at which the SingleTenantHsmInstance was deleted.
Corresponds to the JSON property deleteTime
3708 3709 3710 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3708 def delete_time @delete_time end |
#disable_time ⇒ String
Output only. The time at which the instance will be automatically disabled if
not refreshed. This field is updated upon creation and after each successful
refresh operation and enable. A RefreshSingleTenantHsmInstance operation must
be made via a SingleTenantHsmInstanceProposal before this time otherwise the
SingleTenantHsmInstance will become disabled.
Corresponds to the JSON property disableTime
3717 3718 3719 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3717 def disable_time @disable_time end |
#name ⇒ String
Identifier. The resource name for this SingleTenantHsmInstance in the format
projects/*/locations/*/singleTenantHsmInstances/*.
Corresponds to the JSON property name
3723 3724 3725 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3723 def name @name end |
#quorum_auth ⇒ Google::Apis::CloudkmsV1::QuorumAuth
Configuration for M of N quorum auth.
Corresponds to the JSON property quorumAuth
3728 3729 3730 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3728 def quorum_auth @quorum_auth end |
#state ⇒ String
Output only. The state of the SingleTenantHsmInstance.
Corresponds to the JSON property state
3733 3734 3735 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3733 def state @state end |
#unrefreshed_duration_until_disable ⇒ String
Output only. The system-defined duration that an instance can remain
unrefreshed until it is automatically disabled. This will have a value of 120
days.
Corresponds to the JSON property unrefreshedDurationUntilDisable
3740 3741 3742 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3740 def unrefreshed_duration_until_disable @unrefreshed_duration_until_disable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3747 3748 3749 3750 3751 3752 3753 3754 3755 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3747 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @disable_time = args[:disable_time] if args.key?(:disable_time) @name = args[:name] if args.key?(:name) @quorum_auth = args[:quorum_auth] if args.key?(:quorum_auth) @state = args[:state] if args.key?(:state) @unrefreshed_duration_until_disable = args[:unrefreshed_duration_until_disable] if args.key?(:unrefreshed_duration_until_disable) end |