Class: Google::Apis::CloudkmsV1::SingleTenantHsmInstanceProposal
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::SingleTenantHsmInstanceProposal
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
A SingleTenantHsmInstanceProposal represents a proposal to perform an operation on a SingleTenantHsmInstance.
Instance Attribute Summary collapse
-
#add_quorum_member ⇒ Google::Apis::CloudkmsV1::AddQuorumMember
Add a quorum member to the SingleTenantHsmInstance.
-
#create_time ⇒ String
Output only.
-
#delete_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::DeleteSingleTenantHsmInstance
Delete the SingleTenantHsmInstance.
-
#delete_time ⇒ String
Output only.
-
#disable_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::DisableSingleTenantHsmInstance
Disable the SingleTenantHsmInstance.
-
#enable_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::EnableSingleTenantHsmInstance
Enable the SingleTenantHsmInstance.
-
#expire_time ⇒ String
The time at which the SingleTenantHsmInstanceProposal will expire if not approved and executed.
-
#failure_reason ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#purge_time ⇒ String
Output only.
-
#quorum_parameters ⇒ Google::Apis::CloudkmsV1::QuorumParameters
Parameters of quorum approval for the SingleTenantHsmInstanceProposal.
-
#refresh_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::RefreshSingleTenantHsmInstance
Refreshes the SingleTenantHsmInstance.
-
#register_two_factor_auth_keys ⇒ Google::Apis::CloudkmsV1::RegisterTwoFactorAuthKeys
Register 2FA keys for the SingleTenantHsmInstance.
-
#remove_quorum_member ⇒ Google::Apis::CloudkmsV1::RemoveQuorumMember
Remove a quorum member from the SingleTenantHsmInstance.
-
#required_action_quorum_parameters ⇒ Google::Apis::CloudkmsV1::RequiredActionQuorumParameters
Parameters for an approval that has both required challenges and a quorum.
-
#state ⇒ String
Output only.
-
#ttl ⇒ String
Input only.
-
#upgrade_key_trust ⇒ Google::Apis::CloudkmsV1::UpgradeKeyTrust
Promotes a key with the AES_WRAPPING purpose to a trusted wrapping key.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SingleTenantHsmInstanceProposal
constructor
A new instance of SingleTenantHsmInstanceProposal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SingleTenantHsmInstanceProposal
Returns a new instance of SingleTenantHsmInstanceProposal.
4140 4141 4142 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4140 def initialize(**args) update!(**args) end |
Instance Attribute Details
#add_quorum_member ⇒ Google::Apis::CloudkmsV1::AddQuorumMember
Add a quorum member to the SingleTenantHsmInstance. This will increase the
total_approver_count by 1. The SingleTenantHsmInstance must be in the ACTIVE
state to perform this operation.
Corresponds to the JSON property addQuorumMember
4033 4034 4035 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4033 def add_quorum_member @add_quorum_member end |
#create_time ⇒ String
Output only. The time at which the SingleTenantHsmInstanceProposal was created.
Corresponds to the JSON property createTime
4038 4039 4040 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4038 def create_time @create_time end |
#delete_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::DeleteSingleTenantHsmInstance
Delete the SingleTenantHsmInstance. Deleting a SingleTenantHsmInstance will
make all CryptoKeys attached to the SingleTenantHsmInstance unusable. The
SingleTenantHsmInstance must not be in the DELETING or DELETED state to
perform this operation.
Corresponds to the JSON property deleteSingleTenantHsmInstance
4046 4047 4048 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4046 def delete_single_tenant_hsm_instance @delete_single_tenant_hsm_instance end |
#delete_time ⇒ String
Output only. The time at which the SingleTenantHsmInstanceProposal was deleted.
Corresponds to the JSON property deleteTime
4051 4052 4053 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4051 def delete_time @delete_time end |
#disable_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::DisableSingleTenantHsmInstance
Disable the SingleTenantHsmInstance. The SingleTenantHsmInstance must be in
the ACTIVE state to perform this operation.
Corresponds to the JSON property disableSingleTenantHsmInstance
4057 4058 4059 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4057 def disable_single_tenant_hsm_instance @disable_single_tenant_hsm_instance end |
#enable_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::EnableSingleTenantHsmInstance
Enable the SingleTenantHsmInstance. The SingleTenantHsmInstance must be in the
DISABLED state to perform this operation.
Corresponds to the JSON property enableSingleTenantHsmInstance
4063 4064 4065 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4063 def enable_single_tenant_hsm_instance @enable_single_tenant_hsm_instance end |
#expire_time ⇒ String
The time at which the SingleTenantHsmInstanceProposal will expire if not
approved and executed.
Corresponds to the JSON property expireTime
4069 4070 4071 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4069 def expire_time @expire_time end |
#failure_reason ⇒ String
Output only. The root cause of the most recent failure. Only present if state
is FAILED.
Corresponds to the JSON property failureReason
4075 4076 4077 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4075 def failure_reason @failure_reason end |
#name ⇒ String
Identifier. The resource name for this SingleTenantHsmInstance in the format
projects/*/locations/*/singleTenantHsmInstances/*/proposals/*.
Corresponds to the JSON property name
4081 4082 4083 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4081 def name @name end |
#purge_time ⇒ String
Output only. The time at which the soft-deleted
SingleTenantHsmInstanceProposal will be permanently purged. This field is only
populated when the state is DELETED and will be set a time after expiration of
the proposal, i.e. >= expire_time or (create_time + ttl).
Corresponds to the JSON property purgeTime
4089 4090 4091 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4089 def purge_time @purge_time end |
#quorum_parameters ⇒ Google::Apis::CloudkmsV1::QuorumParameters
Parameters of quorum approval for the SingleTenantHsmInstanceProposal.
Corresponds to the JSON property quorumParameters
4094 4095 4096 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4094 def quorum_parameters @quorum_parameters end |
#refresh_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::RefreshSingleTenantHsmInstance
Refreshes the SingleTenantHsmInstance. This operation must be performed
periodically to keep the SingleTenantHsmInstance active. This operation must
be performed before unrefreshed_duration_until_disable has passed. The
SingleTenantHsmInstance must be in the ACTIVE state to perform this operation.
Corresponds to the JSON property refreshSingleTenantHsmInstance
4102 4103 4104 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4102 def refresh_single_tenant_hsm_instance @refresh_single_tenant_hsm_instance end |
#register_two_factor_auth_keys ⇒ Google::Apis::CloudkmsV1::RegisterTwoFactorAuthKeys
Register 2FA keys for the SingleTenantHsmInstance. This operation requires all
Challenges to be signed by 2FA keys. The SingleTenantHsmInstance must be in
the PENDING_TWO_FACTOR_AUTH_REGISTRATION state to perform this operation.
Corresponds to the JSON property registerTwoFactorAuthKeys
4109 4110 4111 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4109 def register_two_factor_auth_keys @register_two_factor_auth_keys end |
#remove_quorum_member ⇒ Google::Apis::CloudkmsV1::RemoveQuorumMember
Remove a quorum member from the SingleTenantHsmInstance. This will reduce
total_approver_count by 1. The SingleTenantHsmInstance must be in the ACTIVE
state to perform this operation.
Corresponds to the JSON property removeQuorumMember
4116 4117 4118 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4116 def remove_quorum_member @remove_quorum_member end |
#required_action_quorum_parameters ⇒ Google::Apis::CloudkmsV1::RequiredActionQuorumParameters
Parameters for an approval that has both required challenges and a quorum.
Corresponds to the JSON property requiredActionQuorumParameters
4121 4122 4123 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4121 def required_action_quorum_parameters @required_action_quorum_parameters end |
#state ⇒ String
Output only. The state of the SingleTenantHsmInstanceProposal.
Corresponds to the JSON property state
4126 4127 4128 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4126 def state @state end |
#ttl ⇒ String
Input only. The TTL for the SingleTenantHsmInstanceProposal. Proposals will
expire after this duration.
Corresponds to the JSON property ttl
4132 4133 4134 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4132 def ttl @ttl end |
#upgrade_key_trust ⇒ Google::Apis::CloudkmsV1::UpgradeKeyTrust
Promotes a key with the AES_WRAPPING purpose to a trusted wrapping key. The
key must be in the ACTIVE state to perform this operation.
Corresponds to the JSON property upgradeKeyTrust
4138 4139 4140 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4138 def upgrade_key_trust @upgrade_key_trust end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4145 4146 4147 4148 4149 4150 4151 4152 4153 4154 4155 4156 4157 4158 4159 4160 4161 4162 4163 4164 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4145 def update!(**args) @add_quorum_member = args[:add_quorum_member] if args.key?(:add_quorum_member) @create_time = args[:create_time] if args.key?(:create_time) @delete_single_tenant_hsm_instance = args[:delete_single_tenant_hsm_instance] if args.key?(:delete_single_tenant_hsm_instance) @delete_time = args[:delete_time] if args.key?(:delete_time) @disable_single_tenant_hsm_instance = args[:disable_single_tenant_hsm_instance] if args.key?(:disable_single_tenant_hsm_instance) @enable_single_tenant_hsm_instance = args[:enable_single_tenant_hsm_instance] if args.key?(:enable_single_tenant_hsm_instance) @expire_time = args[:expire_time] if args.key?(:expire_time) @failure_reason = args[:failure_reason] if args.key?(:failure_reason) @name = args[:name] if args.key?(:name) @purge_time = args[:purge_time] if args.key?(:purge_time) @quorum_parameters = args[:quorum_parameters] if args.key?(:quorum_parameters) @refresh_single_tenant_hsm_instance = args[:refresh_single_tenant_hsm_instance] if args.key?(:refresh_single_tenant_hsm_instance) @register_two_factor_auth_keys = args[:register_two_factor_auth_keys] if args.key?(:register_two_factor_auth_keys) @remove_quorum_member = args[:remove_quorum_member] if args.key?(:remove_quorum_member) @required_action_quorum_parameters = args[:required_action_quorum_parameters] if args.key?(:required_action_quorum_parameters) @state = args[:state] if args.key?(:state) @ttl = args[:ttl] if args.key?(:ttl) @upgrade_key_trust = args[:upgrade_key_trust] if args.key?(:upgrade_key_trust) end |