Class: Google::Apis::CloudkmsV1::SingleTenantHsmInstanceProposal
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::SingleTenantHsmInstanceProposal
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
A SingleTenantHsmInstanceProposal represents a proposal to perform an operation on a SingleTenantHsmInstance.
Instance Attribute Summary collapse
-
#add_quorum_member ⇒ Google::Apis::CloudkmsV1::AddQuorumMember
Add a quorum member to the SingleTenantHsmInstance.
-
#create_time ⇒ String
Output only.
-
#delete_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::DeleteSingleTenantHsmInstance
Delete the SingleTenantHsmInstance.
-
#delete_time ⇒ String
Output only.
-
#disable_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::DisableSingleTenantHsmInstance
Disable the SingleTenantHsmInstance.
-
#enable_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::EnableSingleTenantHsmInstance
Enable the SingleTenantHsmInstance.
-
#expire_time ⇒ String
The time at which the SingleTenantHsmInstanceProposal will expire if not approved and executed.
-
#failure_reason ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#purge_time ⇒ String
Output only.
-
#quorum_parameters ⇒ Google::Apis::CloudkmsV1::QuorumParameters
Parameters of quorum approval for the SingleTenantHsmInstanceProposal.
-
#refresh_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::RefreshSingleTenantHsmInstance
Refreshes the SingleTenantHsmInstance.
-
#register_two_factor_auth_keys ⇒ Google::Apis::CloudkmsV1::RegisterTwoFactorAuthKeys
Register 2FA keys for the SingleTenantHsmInstance.
-
#remove_quorum_member ⇒ Google::Apis::CloudkmsV1::RemoveQuorumMember
Remove a quorum member from the SingleTenantHsmInstance.
-
#required_action_quorum_parameters ⇒ Google::Apis::CloudkmsV1::RequiredActionQuorumParameters
Parameters for an approval that has both required challenges and a quorum.
-
#state ⇒ String
Output only.
-
#ttl ⇒ String
Input only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SingleTenantHsmInstanceProposal
constructor
A new instance of SingleTenantHsmInstanceProposal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SingleTenantHsmInstanceProposal
Returns a new instance of SingleTenantHsmInstanceProposal.
3995 3996 3997 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3995 def initialize(**args) update!(**args) end |
Instance Attribute Details
#add_quorum_member ⇒ Google::Apis::CloudkmsV1::AddQuorumMember
Add a quorum member to the SingleTenantHsmInstance. This will increase the
total_approver_count by 1. The SingleTenantHsmInstance must be in the ACTIVE
state to perform this operation.
Corresponds to the JSON property addQuorumMember
3894 3895 3896 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3894 def add_quorum_member @add_quorum_member end |
#create_time ⇒ String
Output only. The time at which the SingleTenantHsmInstanceProposal was created.
Corresponds to the JSON property createTime
3899 3900 3901 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3899 def create_time @create_time end |
#delete_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::DeleteSingleTenantHsmInstance
Delete the SingleTenantHsmInstance. Deleting a SingleTenantHsmInstance will
make all CryptoKeys attached to the SingleTenantHsmInstance unusable. The
SingleTenantHsmInstance must not be in the DELETING or DELETED state to
perform this operation.
Corresponds to the JSON property deleteSingleTenantHsmInstance
3907 3908 3909 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3907 def delete_single_tenant_hsm_instance @delete_single_tenant_hsm_instance end |
#delete_time ⇒ String
Output only. The time at which the SingleTenantHsmInstanceProposal was deleted.
Corresponds to the JSON property deleteTime
3912 3913 3914 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3912 def delete_time @delete_time end |
#disable_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::DisableSingleTenantHsmInstance
Disable the SingleTenantHsmInstance. The SingleTenantHsmInstance must be in
the ACTIVE state to perform this operation.
Corresponds to the JSON property disableSingleTenantHsmInstance
3918 3919 3920 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3918 def disable_single_tenant_hsm_instance @disable_single_tenant_hsm_instance end |
#enable_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::EnableSingleTenantHsmInstance
Enable the SingleTenantHsmInstance. The SingleTenantHsmInstance must be in the
DISABLED state to perform this operation.
Corresponds to the JSON property enableSingleTenantHsmInstance
3924 3925 3926 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3924 def enable_single_tenant_hsm_instance @enable_single_tenant_hsm_instance end |
#expire_time ⇒ String
The time at which the SingleTenantHsmInstanceProposal will expire if not
approved and executed.
Corresponds to the JSON property expireTime
3930 3931 3932 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3930 def expire_time @expire_time end |
#failure_reason ⇒ String
Output only. The root cause of the most recent failure. Only present if state
is FAILED.
Corresponds to the JSON property failureReason
3936 3937 3938 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3936 def failure_reason @failure_reason end |
#name ⇒ String
Identifier. The resource name for this SingleTenantHsmInstance in the format
projects/*/locations/*/singleTenantHsmInstances/*/proposals/*.
Corresponds to the JSON property name
3942 3943 3944 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3942 def name @name end |
#purge_time ⇒ String
Output only. The time at which the soft-deleted
SingleTenantHsmInstanceProposal will be permanently purged. This field is only
populated when the state is DELETED and will be set a time after expiration of
the proposal, i.e. >= expire_time or (create_time + ttl).
Corresponds to the JSON property purgeTime
3950 3951 3952 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3950 def purge_time @purge_time end |
#quorum_parameters ⇒ Google::Apis::CloudkmsV1::QuorumParameters
Parameters of quorum approval for the SingleTenantHsmInstanceProposal.
Corresponds to the JSON property quorumParameters
3955 3956 3957 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3955 def quorum_parameters @quorum_parameters end |
#refresh_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::RefreshSingleTenantHsmInstance
Refreshes the SingleTenantHsmInstance. This operation must be performed
periodically to keep the SingleTenantHsmInstance active. This operation must
be performed before unrefreshed_duration_until_disable has passed. The
SingleTenantHsmInstance must be in the ACTIVE state to perform this operation.
Corresponds to the JSON property refreshSingleTenantHsmInstance
3963 3964 3965 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3963 def refresh_single_tenant_hsm_instance @refresh_single_tenant_hsm_instance end |
#register_two_factor_auth_keys ⇒ Google::Apis::CloudkmsV1::RegisterTwoFactorAuthKeys
Register 2FA keys for the SingleTenantHsmInstance. This operation requires all
Challenges to be signed by 2FA keys. The SingleTenantHsmInstance must be in
the PENDING_TWO_FACTOR_AUTH_REGISTRATION state to perform this operation.
Corresponds to the JSON property registerTwoFactorAuthKeys
3970 3971 3972 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3970 def register_two_factor_auth_keys @register_two_factor_auth_keys end |
#remove_quorum_member ⇒ Google::Apis::CloudkmsV1::RemoveQuorumMember
Remove a quorum member from the SingleTenantHsmInstance. This will reduce
total_approver_count by 1. The SingleTenantHsmInstance must be in the ACTIVE
state to perform this operation.
Corresponds to the JSON property removeQuorumMember
3977 3978 3979 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3977 def remove_quorum_member @remove_quorum_member end |
#required_action_quorum_parameters ⇒ Google::Apis::CloudkmsV1::RequiredActionQuorumParameters
Parameters for an approval that has both required challenges and a quorum.
Corresponds to the JSON property requiredActionQuorumParameters
3982 3983 3984 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3982 def required_action_quorum_parameters @required_action_quorum_parameters end |
#state ⇒ String
Output only. The state of the SingleTenantHsmInstanceProposal.
Corresponds to the JSON property state
3987 3988 3989 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3987 def state @state end |
#ttl ⇒ String
Input only. The TTL for the SingleTenantHsmInstanceProposal. Proposals will
expire after this duration.
Corresponds to the JSON property ttl
3993 3994 3995 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3993 def ttl @ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4000 4001 4002 4003 4004 4005 4006 4007 4008 4009 4010 4011 4012 4013 4014 4015 4016 4017 4018 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4000 def update!(**args) @add_quorum_member = args[:add_quorum_member] if args.key?(:add_quorum_member) @create_time = args[:create_time] if args.key?(:create_time) @delete_single_tenant_hsm_instance = args[:delete_single_tenant_hsm_instance] if args.key?(:delete_single_tenant_hsm_instance) @delete_time = args[:delete_time] if args.key?(:delete_time) @disable_single_tenant_hsm_instance = args[:disable_single_tenant_hsm_instance] if args.key?(:disable_single_tenant_hsm_instance) @enable_single_tenant_hsm_instance = args[:enable_single_tenant_hsm_instance] if args.key?(:enable_single_tenant_hsm_instance) @expire_time = args[:expire_time] if args.key?(:expire_time) @failure_reason = args[:failure_reason] if args.key?(:failure_reason) @name = args[:name] if args.key?(:name) @purge_time = args[:purge_time] if args.key?(:purge_time) @quorum_parameters = args[:quorum_parameters] if args.key?(:quorum_parameters) @refresh_single_tenant_hsm_instance = args[:refresh_single_tenant_hsm_instance] if args.key?(:refresh_single_tenant_hsm_instance) @register_two_factor_auth_keys = args[:register_two_factor_auth_keys] if args.key?(:register_two_factor_auth_keys) @remove_quorum_member = args[:remove_quorum_member] if args.key?(:remove_quorum_member) @required_action_quorum_parameters = args[:required_action_quorum_parameters] if args.key?(:required_action_quorum_parameters) @state = args[:state] if args.key?(:state) @ttl = args[:ttl] if args.key?(:ttl) end |