Class: Google::Apis::CloudkmsV1::SingleTenantHsmInstanceProposal

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

A SingleTenantHsmInstanceProposal represents a proposal to perform an operation on a SingleTenantHsmInstance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SingleTenantHsmInstanceProposal

Returns a new instance of SingleTenantHsmInstanceProposal.



3994
3995
3996
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3994

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#add_quorum_memberGoogle::Apis::CloudkmsV1::AddQuorumMember

Add a quorum member to the SingleTenantHsmInstance. This will increase the total_approver_count by 1. The SingleTenantHsmInstance must be in the ACTIVE state to perform this operation. Corresponds to the JSON property addQuorumMember



3893
3894
3895
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3893

def add_quorum_member
  @add_quorum_member
end

#create_timeString

Output only. The time at which the SingleTenantHsmInstanceProposal was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3898
3899
3900
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3898

def create_time
  @create_time
end

#delete_single_tenant_hsm_instanceGoogle::Apis::CloudkmsV1::DeleteSingleTenantHsmInstance

Delete the SingleTenantHsmInstance. Deleting a SingleTenantHsmInstance will make all CryptoKeys attached to the SingleTenantHsmInstance unusable. The SingleTenantHsmInstance must not be in the DELETING or DELETED state to perform this operation. Corresponds to the JSON property deleteSingleTenantHsmInstance



3906
3907
3908
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3906

def delete_single_tenant_hsm_instance
  @delete_single_tenant_hsm_instance
end

#delete_timeString

Output only. The time at which the SingleTenantHsmInstanceProposal was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


3911
3912
3913
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3911

def delete_time
  @delete_time
end

#disable_single_tenant_hsm_instanceGoogle::Apis::CloudkmsV1::DisableSingleTenantHsmInstance

Disable the SingleTenantHsmInstance. The SingleTenantHsmInstance must be in the ACTIVE state to perform this operation. Corresponds to the JSON property disableSingleTenantHsmInstance



3917
3918
3919
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3917

def disable_single_tenant_hsm_instance
  @disable_single_tenant_hsm_instance
end

#enable_single_tenant_hsm_instanceGoogle::Apis::CloudkmsV1::EnableSingleTenantHsmInstance

Enable the SingleTenantHsmInstance. The SingleTenantHsmInstance must be in the DISABLED state to perform this operation. Corresponds to the JSON property enableSingleTenantHsmInstance



3923
3924
3925
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3923

def enable_single_tenant_hsm_instance
  @enable_single_tenant_hsm_instance
end

#expire_timeString

The time at which the SingleTenantHsmInstanceProposal will expire if not approved and executed. Corresponds to the JSON property expireTime

Returns:

  • (String)


3929
3930
3931
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3929

def expire_time
  @expire_time
end

#failure_reasonString

Output only. The root cause of the most recent failure. Only present if state is FAILED. Corresponds to the JSON property failureReason

Returns:

  • (String)


3935
3936
3937
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3935

def failure_reason
  @failure_reason
end

#nameString

Identifier. The resource name for this SingleTenantHsmInstance in the format projects/*/locations/*/singleTenantHsmInstances/*/proposals/*. Corresponds to the JSON property name

Returns:

  • (String)


3941
3942
3943
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3941

def name
  @name
end

#purge_timeString

Output only. The time at which the soft-deleted SingleTenantHsmInstanceProposal will be permanently purged. This field is only populated when the state is DELETED and will be set a time after expiration of the proposal, i.e. >= expire_time or (create_time + ttl). Corresponds to the JSON property purgeTime

Returns:

  • (String)


3949
3950
3951
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3949

def purge_time
  @purge_time
end

#quorum_parametersGoogle::Apis::CloudkmsV1::QuorumParameters

Parameters of quorum approval for the SingleTenantHsmInstanceProposal. Corresponds to the JSON property quorumParameters



3954
3955
3956
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3954

def quorum_parameters
  @quorum_parameters
end

#refresh_single_tenant_hsm_instanceGoogle::Apis::CloudkmsV1::RefreshSingleTenantHsmInstance

Refreshes the SingleTenantHsmInstance. This operation must be performed periodically to keep the SingleTenantHsmInstance active. This operation must be performed before unrefreshed_duration_until_disable has passed. The SingleTenantHsmInstance must be in the ACTIVE state to perform this operation. Corresponds to the JSON property refreshSingleTenantHsmInstance



3962
3963
3964
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3962

def refresh_single_tenant_hsm_instance
  @refresh_single_tenant_hsm_instance
end

#register_two_factor_auth_keysGoogle::Apis::CloudkmsV1::RegisterTwoFactorAuthKeys

Register 2FA keys for the SingleTenantHsmInstance. This operation requires all Challenges to be signed by 2FA keys. The SingleTenantHsmInstance must be in the PENDING_TWO_FACTOR_AUTH_REGISTRATION state to perform this operation. Corresponds to the JSON property registerTwoFactorAuthKeys



3969
3970
3971
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3969

def register_two_factor_auth_keys
  @register_two_factor_auth_keys
end

#remove_quorum_memberGoogle::Apis::CloudkmsV1::RemoveQuorumMember

Remove a quorum member from the SingleTenantHsmInstance. This will reduce total_approver_count by 1. The SingleTenantHsmInstance must be in the ACTIVE state to perform this operation. Corresponds to the JSON property removeQuorumMember



3976
3977
3978
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3976

def remove_quorum_member
  @remove_quorum_member
end

#required_action_quorum_parametersGoogle::Apis::CloudkmsV1::RequiredActionQuorumParameters

Parameters for an approval that has both required challenges and a quorum. Corresponds to the JSON property requiredActionQuorumParameters



3981
3982
3983
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3981

def required_action_quorum_parameters
  @required_action_quorum_parameters
end

#stateString

Output only. The state of the SingleTenantHsmInstanceProposal. Corresponds to the JSON property state

Returns:

  • (String)


3986
3987
3988
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3986

def state
  @state
end

#ttlString

Input only. The TTL for the SingleTenantHsmInstanceProposal. Proposals will expire after this duration. Corresponds to the JSON property ttl

Returns:

  • (String)


3992
3993
3994
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3992

def ttl
  @ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3999

def update!(**args)
  @add_quorum_member = args[:add_quorum_member] if args.key?(:add_quorum_member)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_single_tenant_hsm_instance = args[:delete_single_tenant_hsm_instance] if args.key?(:delete_single_tenant_hsm_instance)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @disable_single_tenant_hsm_instance = args[:disable_single_tenant_hsm_instance] if args.key?(:disable_single_tenant_hsm_instance)
  @enable_single_tenant_hsm_instance = args[:enable_single_tenant_hsm_instance] if args.key?(:enable_single_tenant_hsm_instance)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @failure_reason = args[:failure_reason] if args.key?(:failure_reason)
  @name = args[:name] if args.key?(:name)
  @purge_time = args[:purge_time] if args.key?(:purge_time)
  @quorum_parameters = args[:quorum_parameters] if args.key?(:quorum_parameters)
  @refresh_single_tenant_hsm_instance = args[:refresh_single_tenant_hsm_instance] if args.key?(:refresh_single_tenant_hsm_instance)
  @register_two_factor_auth_keys = args[:register_two_factor_auth_keys] if args.key?(:register_two_factor_auth_keys)
  @remove_quorum_member = args[:remove_quorum_member] if args.key?(:remove_quorum_member)
  @required_action_quorum_parameters = args[:required_action_quorum_parameters] if args.key?(:required_action_quorum_parameters)
  @state = args[:state] if args.key?(:state)
  @ttl = args[:ttl] if args.key?(:ttl)
end