Class: Google::Apis::CloudkmsV1::SingleTenantHsmInstanceProposal
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::SingleTenantHsmInstanceProposal
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
A SingleTenantHsmInstanceProposal represents a proposal to perform an operation on a SingleTenantHsmInstance.
Instance Attribute Summary collapse
-
#add_quorum_member ⇒ Google::Apis::CloudkmsV1::AddQuorumMember
Add a quorum member to the SingleTenantHsmInstance.
-
#create_time ⇒ String
Output only.
-
#delete_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::DeleteSingleTenantHsmInstance
Delete the SingleTenantHsmInstance.
-
#delete_time ⇒ String
Output only.
-
#disable_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::DisableSingleTenantHsmInstance
Disable the SingleTenantHsmInstance.
-
#enable_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::EnableSingleTenantHsmInstance
Enable the SingleTenantHsmInstance.
-
#expire_time ⇒ String
The time at which the SingleTenantHsmInstanceProposal will expire if not approved and executed.
-
#failure_reason ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#purge_time ⇒ String
Output only.
-
#quorum_parameters ⇒ Google::Apis::CloudkmsV1::QuorumParameters
Parameters of quorum approval for the SingleTenantHsmInstanceProposal.
-
#refresh_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::RefreshSingleTenantHsmInstance
Refreshes the SingleTenantHsmInstance.
-
#register_two_factor_auth_keys ⇒ Google::Apis::CloudkmsV1::RegisterTwoFactorAuthKeys
Register 2FA keys for the SingleTenantHsmInstance.
-
#remove_quorum_member ⇒ Google::Apis::CloudkmsV1::RemoveQuorumMember
Remove a quorum member from the SingleTenantHsmInstance.
-
#required_action_quorum_parameters ⇒ Google::Apis::CloudkmsV1::RequiredActionQuorumParameters
Parameters for an approval that has both required challenges and a quorum.
-
#state ⇒ String
Output only.
-
#ttl ⇒ String
Input only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SingleTenantHsmInstanceProposal
constructor
A new instance of SingleTenantHsmInstanceProposal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SingleTenantHsmInstanceProposal
Returns a new instance of SingleTenantHsmInstanceProposal.
3960 3961 3962 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3960 def initialize(**args) update!(**args) end |
Instance Attribute Details
#add_quorum_member ⇒ Google::Apis::CloudkmsV1::AddQuorumMember
Add a quorum member to the SingleTenantHsmInstance. This will increase the
total_approver_count by 1. The SingleTenantHsmInstance must be in the ACTIVE
state to perform this operation.
Corresponds to the JSON property addQuorumMember
3859 3860 3861 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3859 def add_quorum_member @add_quorum_member end |
#create_time ⇒ String
Output only. The time at which the SingleTenantHsmInstanceProposal was created.
Corresponds to the JSON property createTime
3864 3865 3866 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3864 def create_time @create_time end |
#delete_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::DeleteSingleTenantHsmInstance
Delete the SingleTenantHsmInstance. Deleting a SingleTenantHsmInstance will
make all CryptoKeys attached to the SingleTenantHsmInstance unusable. The
SingleTenantHsmInstance must not be in the DELETING or DELETED state to
perform this operation.
Corresponds to the JSON property deleteSingleTenantHsmInstance
3872 3873 3874 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3872 def delete_single_tenant_hsm_instance @delete_single_tenant_hsm_instance end |
#delete_time ⇒ String
Output only. The time at which the SingleTenantHsmInstanceProposal was deleted.
Corresponds to the JSON property deleteTime
3877 3878 3879 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3877 def delete_time @delete_time end |
#disable_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::DisableSingleTenantHsmInstance
Disable the SingleTenantHsmInstance. The SingleTenantHsmInstance must be in
the ACTIVE state to perform this operation.
Corresponds to the JSON property disableSingleTenantHsmInstance
3883 3884 3885 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3883 def disable_single_tenant_hsm_instance @disable_single_tenant_hsm_instance end |
#enable_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::EnableSingleTenantHsmInstance
Enable the SingleTenantHsmInstance. The SingleTenantHsmInstance must be in the
DISABLED state to perform this operation.
Corresponds to the JSON property enableSingleTenantHsmInstance
3889 3890 3891 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3889 def enable_single_tenant_hsm_instance @enable_single_tenant_hsm_instance end |
#expire_time ⇒ String
The time at which the SingleTenantHsmInstanceProposal will expire if not
approved and executed.
Corresponds to the JSON property expireTime
3895 3896 3897 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3895 def expire_time @expire_time end |
#failure_reason ⇒ String
Output only. The root cause of the most recent failure. Only present if state
is FAILED.
Corresponds to the JSON property failureReason
3901 3902 3903 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3901 def failure_reason @failure_reason end |
#name ⇒ String
Identifier. The resource name for this SingleTenantHsmInstance in the format
projects/*/locations/*/singleTenantHsmInstances/*/proposals/*.
Corresponds to the JSON property name
3907 3908 3909 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3907 def name @name end |
#purge_time ⇒ String
Output only. The time at which the soft-deleted
SingleTenantHsmInstanceProposal will be permanently purged. This field is only
populated when the state is DELETED and will be set a time after expiration of
the proposal, i.e. >= expire_time or (create_time + ttl).
Corresponds to the JSON property purgeTime
3915 3916 3917 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3915 def purge_time @purge_time end |
#quorum_parameters ⇒ Google::Apis::CloudkmsV1::QuorumParameters
Parameters of quorum approval for the SingleTenantHsmInstanceProposal.
Corresponds to the JSON property quorumParameters
3920 3921 3922 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3920 def quorum_parameters @quorum_parameters end |
#refresh_single_tenant_hsm_instance ⇒ Google::Apis::CloudkmsV1::RefreshSingleTenantHsmInstance
Refreshes the SingleTenantHsmInstance. This operation must be performed
periodically to keep the SingleTenantHsmInstance active. This operation must
be performed before unrefreshed_duration_until_disable has passed. The
SingleTenantHsmInstance must be in the ACTIVE state to perform this operation.
Corresponds to the JSON property refreshSingleTenantHsmInstance
3928 3929 3930 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3928 def refresh_single_tenant_hsm_instance @refresh_single_tenant_hsm_instance end |
#register_two_factor_auth_keys ⇒ Google::Apis::CloudkmsV1::RegisterTwoFactorAuthKeys
Register 2FA keys for the SingleTenantHsmInstance. This operation requires all
Challenges to be signed by 2FA keys. The SingleTenantHsmInstance must be in
the PENDING_TWO_FACTOR_AUTH_REGISTRATION state to perform this operation.
Corresponds to the JSON property registerTwoFactorAuthKeys
3935 3936 3937 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3935 def register_two_factor_auth_keys @register_two_factor_auth_keys end |
#remove_quorum_member ⇒ Google::Apis::CloudkmsV1::RemoveQuorumMember
Remove a quorum member from the SingleTenantHsmInstance. This will reduce
total_approver_count by 1. The SingleTenantHsmInstance must be in the ACTIVE
state to perform this operation.
Corresponds to the JSON property removeQuorumMember
3942 3943 3944 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3942 def remove_quorum_member @remove_quorum_member end |
#required_action_quorum_parameters ⇒ Google::Apis::CloudkmsV1::RequiredActionQuorumParameters
Parameters for an approval that has both required challenges and a quorum.
Corresponds to the JSON property requiredActionQuorumParameters
3947 3948 3949 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3947 def required_action_quorum_parameters @required_action_quorum_parameters end |
#state ⇒ String
Output only. The state of the SingleTenantHsmInstanceProposal.
Corresponds to the JSON property state
3952 3953 3954 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3952 def state @state end |
#ttl ⇒ String
Input only. The TTL for the SingleTenantHsmInstanceProposal. Proposals will
expire after this duration.
Corresponds to the JSON property ttl
3958 3959 3960 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3958 def ttl @ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3965 3966 3967 3968 3969 3970 3971 3972 3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 3965 def update!(**args) @add_quorum_member = args[:add_quorum_member] if args.key?(:add_quorum_member) @create_time = args[:create_time] if args.key?(:create_time) @delete_single_tenant_hsm_instance = args[:delete_single_tenant_hsm_instance] if args.key?(:delete_single_tenant_hsm_instance) @delete_time = args[:delete_time] if args.key?(:delete_time) @disable_single_tenant_hsm_instance = args[:disable_single_tenant_hsm_instance] if args.key?(:disable_single_tenant_hsm_instance) @enable_single_tenant_hsm_instance = args[:enable_single_tenant_hsm_instance] if args.key?(:enable_single_tenant_hsm_instance) @expire_time = args[:expire_time] if args.key?(:expire_time) @failure_reason = args[:failure_reason] if args.key?(:failure_reason) @name = args[:name] if args.key?(:name) @purge_time = args[:purge_time] if args.key?(:purge_time) @quorum_parameters = args[:quorum_parameters] if args.key?(:quorum_parameters) @refresh_single_tenant_hsm_instance = args[:refresh_single_tenant_hsm_instance] if args.key?(:refresh_single_tenant_hsm_instance) @register_two_factor_auth_keys = args[:register_two_factor_auth_keys] if args.key?(:register_two_factor_auth_keys) @remove_quorum_member = args[:remove_quorum_member] if args.key?(:remove_quorum_member) @required_action_quorum_parameters = args[:required_action_quorum_parameters] if args.key?(:required_action_quorum_parameters) @state = args[:state] if args.key?(:state) @ttl = args[:ttl] if args.key?(:ttl) end |