Class: Google::Apis::CloudkmsV1::WrappingPublicKey

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

The public key component of the wrapping key. For details of the type of key this public key corresponds to, see the ImportMethod.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WrappingPublicKey

Returns a new instance of WrappingPublicKey.



4156
4157
4158
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4156

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataString

Output only. Contains the public key, formatted according to the PublicKey. PublicKeyFormat specified in the KeyManagementService.GetImportJob request. Corresponds to the JSON property data NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


4142
4143
4144
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4142

def data
  @data
end

#pemString

The public key, encoded in PEM format. For more information, see the RFC 7468 sections for General Considerations and Textual Encoding of Subject Public Key Info. This field gets populated by default for RSA-based import methods, if no public_key_format is specified in the request. If you want to retrieve the wrapping key of an ImportJob in some other format, use KeyManagementService. GetImportJob and set the public_key_format to the desired public key format. Corresponds to the JSON property pem

Returns:

  • (String)


4154
4155
4156
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4154

def pem
  @pem
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4161
4162
4163
4164
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4161

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @pem = args[:pem] if args.key?(:pem)
end