Class: Google::Apis::CloudkmsV1::WrappingPublicKey
- Inherits:
-
Object
- Object
- Google::Apis::CloudkmsV1::WrappingPublicKey
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb
Overview
The public key component of the wrapping key. For details of the type of key this public key corresponds to, see the ImportMethod.
Instance Attribute Summary collapse
-
#data ⇒ String
Output only.
-
#pem ⇒ String
The public key, encoded in PEM format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WrappingPublicKey
constructor
A new instance of WrappingPublicKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WrappingPublicKey
Returns a new instance of WrappingPublicKey.
4155 4156 4157 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4155 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ String
Output only. Contains the public key, formatted according to the PublicKey.
PublicKeyFormat specified in the KeyManagementService.GetImportJob request.
Corresponds to the JSON property data
NOTE: Values are automatically base64 encoded/decoded in the client library.
4141 4142 4143 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4141 def data @data end |
#pem ⇒ String
The public key, encoded in PEM format. For more information, see the RFC 7468 sections for General Considerations and Textual Encoding of
Subject Public Key Info.
This field gets populated by default for RSA-based import methods, if no
public_key_format is specified in the request. If you want to retrieve the
wrapping key of an ImportJob in some other format, use KeyManagementService.
GetImportJob and set the public_key_format to the desired public key format.
Corresponds to the JSON property pem
4153 4154 4155 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4153 def pem @pem end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4160 4161 4162 4163 |
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4160 def update!(**args) @data = args[:data] if args.key?(:data) @pem = args[:pem] if args.key?(:pem) end |