Class: Google::Apis::CloudkmsV1::WrappingPublicKey

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudkms_v1/classes.rb,
lib/google/apis/cloudkms_v1/representations.rb,
lib/google/apis/cloudkms_v1/representations.rb

Overview

The public key component of the wrapping key. For details of the type of key this public key corresponds to, see the ImportMethod.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WrappingPublicKey

Returns a new instance of WrappingPublicKey.



4110
4111
4112
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4110

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pemString

The public key, encoded in PEM format. For more information, see the RFC 7468 sections for General Considerations and Textual Encoding of Subject Public Key Info. Corresponds to the JSON property pem

Returns:

  • (String)


4108
4109
4110
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4108

def pem
  @pem
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4115
4116
4117
# File 'lib/google/apis/cloudkms_v1/classes.rb', line 4115

def update!(**args)
  @pem = args[:pem] if args.key?(:pem)
end